Avikro Industries Proprietary Limited - 1982-008520-07 - 2019

https://xbrl.cipc.co.za/taxonomy/ca/enum#SouthAfricanInstituteOfCharteredAccountants Liz Willis 5204 Please provide this report either in a non-printing section or a printed area. 1 3 CHURCH Vereeniging ZAF FALSE https://xbrl.cipc.co.za/taxonomy/ca/enum#DomesticPrivateCompany info@Avikro.co.za True True True True False https://xbrl.cipc.co.za/taxonomy/ca/enum#Unqualified 0 0 520 372 https://xbrl.cipc.co.za/taxonomy/ca/enum#Audited 2 237 417 https://xbrl.cipc.co.za/taxonomy/ca/enum#AuditedConsolidatedAnnualFinancialStatements 3 343 674 The Workiva Platform 2024-07-24
This is a zero!
cil:public_interest_score cil:employee cil:person iso4217:ZAR 1982/008520/07 2018-07-01 2019-06-30 1982/008520/07 2019-06-30 1982/008520/07 2017-07-01 2018-06-30 1982/008520/07 2018-06-30 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:IssuedCapitalMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:TreasurySharesMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:ReserveOfSharebasedPaymentsMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:OtherReservesMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:ReserveOfExchangeDifferencesOnTranslationMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:RetainedEarningsMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:EquityAttributableToOwnersOfParentMember 1982/008520/07 2018-07-01 2019-06-30 ifrs-full:NoncontrollingInterestsMember 1982/008520/07 2019-06-30 ifrs-full:IssuedCapitalMember 1982/008520/07 2019-06-30 ifrs-full:TreasurySharesMember 1982/008520/07 2019-06-30 ifrs-full:ReserveOfSharebasedPaymentsMember 1982/008520/07 2019-06-30 ifrs-full:OtherReservesMember 1982/008520/07 2019-06-30 ifrs-full:ReserveOfExchangeDifferencesOnTranslationMember 1982/008520/07 2019-06-30 ifrs-full:RetainedEarningsMember 1982/008520/07 2019-06-30 ifrs-full:EquityAttributableToOwnersOfParentMember 1982/008520/07 2019-06-30 ifrs-full:NoncontrollingInterestsMember 1982/008520/07 2017-06-30 1982/008520/07 2018-07-01 2019-06-30 1 1982/008520/07 2018-07-01 2019-06-30 2 1982/008520/07 2018-07-01 2019-06-30 3
Avikro Industries Proprietary Limited
(Reg. No. 1982/008520/06)
Group annual financial statements and annual financial statements
for the year ended 06/30/2019
Audited

Ceramic Industries Proprietary Limited
(Reg. No. 1982/008520/07)

Group annual financial statements and annual financial statements
for the year ended 30 June 2019
The reports and statements set out below comprise the group annual financial statements and annual financial statements presented to the shareholders -

Contents | Page
Directors’ responsibility statement | 2
Certificate of the Company Secretary | 2
Directors’ report | 3
Audit Committee's report | 8
Independent auditor’s report | 10
Statements of profit or loss and other comprehensive income | 12
Statements of financial position | 13
Statements of changes in equity | 14
Statements of cash flows | 17
Accounting policies | 18
Notes to the financial statements | 30

The Group financial statements and financial statements of Avikro Industries Proprietary Limited have been audited in terms of S30 of the Companies Act.
The Group annual financial statements and annual financial statements for the year ended 30 June 2019 have been prepared under the supervision of the Group Financial Manager, AM Aucamp, and were published on 4 October 2018.
1

Avikro Industries Proprietary Limited
Directors’ responsibility statement
The directors are responsible for the preparation and fair presentation of the group financial statements and financial statements of Avikro Industries Proprietary Limited, comprising the statements of financial position as at 30 June 2019, and the statements of profit or loss and other comprehensive income, changes in equity and cash flows for the year then ended, and the notes to the financial statements which include a summary of significant accounting policies and other explanatory notes, in accordance with International Financial Reporting Standards and the requirements of the Companies Act of South Africa. In addition, the directors are also responsible for preparing the directors’ report.
The directors are also responsible for such internal control as the directors determine is necessary to enable the preparation of financial statements that are free from material misstatement, whether due to fraud or error, and for maintaining adequate accounting records and an effective system of risk management.
The directors have made an assessment of the ability of the company, its subsidiaries and its associate to continue as going concerns and have no reason to believe that the businesses will not be going concerns in the year ahead.
The auditor is responsible for reporting on whether the consolidated and separate financial statements are fairly presented in accordance with the applicable financial reporting framework.
Approval of group annual financial statements and annual financial statements
The group annual financial statements and annual financial statements of Avikro Industries Proprietary Limited, as identified in the first paragraph, were approved by the directors on 4 October 2018 and signed, on their behalf by -
___________________
LA Foxcroft
Chief Executive Officer
Certificate of the Company Secretary
In my capacity as Company Secretary, I hereby certify that for the year ended 30 June 2019, the company has filed all such returns and notices as required by the Companies Act 71 of 2008 and that all such returns appear to be true, correct and up-to-date.
___________________
EJ Willis
Company Secretary
04 October 2018
2

Avikro Industries Proprietary Limited
Directors’ report
for the year ended 30 June 2018
The directors of Avikro Industries Proprietary Limited (“Avikro” or “the company”) present the annual financial statements for the year ended 30 June 2018.
The term “Group” refers to the company, its associate and its subsidiaries. The associate and a list of subsidiaries appear in notes 8 and 9.
Scope and boundary
The report covers the Group’s operations in South Africa and Australia.
There have been no material changes to the structure, products and services of the organisation since the release of the previous report for the year ended 30 June 2017, and hence the scope of the current report remains largely unchanged.
Nature of business
Avikro and its subsidiaries manufacture Avikro floor tiles, wall tiles, vitreous china sanitaryware and acrylic bathroomware. The Group is the largest Southern African manufacturer and supplier of Avikro tiles and sanitaryware and is the largest local manufacturer of Avikro tiles in Australia.
Avikro’s South African operation comprises five tile factories, one sanitaryware factory and one bath factory. The Samca Wall Tiles and Samca Floor Tiles factories are located in Babelegi, whilst the Pegasus,Vitro and Gryphon tile factories are situated in Vereeniging. The sanitaryware factory, Betta Sanitaryware, and the bath factory, Aquarius, are both located in Krugersdorp. The Australian operation comprises one glazed porcelain tile factory situated in Rutherford in New South Wales.
Statement of responsibility
The responsibilities of the Group’s directors are detailed on page 2.
Group results
The Group applied International Financial Reporting Standards (“IFRS”) for the year under review. The results of the Group and the company are set out on pages 12 to 58.
Property, plant and equipment
During the year the Group spent R314.5 million on new plant and machinery in order to upgrade the technology in the factories and to expand its operations. Details of property, plant and equipment are contained in note 6 of the financial statements.
The register of land and buildings is available for inspection at the registered office of the company during normal business hours.
Dividends
The Board has declared a final dividend of 400 cents per share (2017 - 740 cents per share) which, together with the interim dividend of 300 cents per share (2017 - 350 cents per share) amounts to a total dividend of 700 cents per share (2017 - 1 090 cents per share) for the year.
The capital remaining after the payment of the above dividend is considered sufficient by the Board to support current operations and future developments of the Group.
3

Avikro Industries Proprietary Limited
Directors’ report
for the year ended 30 June 2018 (continued)
Shareholders and capital
The authorised and issued share capital at 30 June 2019 as per note 13 is:

Authorised |  |
27 709 467 | - | ordinary shares of no par value
Issued |  |
19 391 700 | - | ordinary shares of no par value

The Avikro Industries Proprietary Limited Equity Incentive Scheme
Following the termination of the Trust and the Share Appreciation Rights Scheme ("SARS") and Long Term Incentive Plan ("LTIP") schemes and in accordance with the terms of the offer made by Italtile to Avikro shareholders in October 2012, the Board has implemented a new share incentive scheme.
The scheme, known as the Avikro Industries Proprietary Limited Equity Incentive Scheme (“EIS”) was implemented with effect from 1 July 2013. The purpose of the scheme is to incentivise selected employees by giving them the opportunity to acquire shares in Avikro. The scheme will also ensure that the goals of those employees will be aligned with the goals of the other shareholders.
The Board has agreed to allocate a maximum of 20% of the total number of shares in issue to the EIS and has set a maximum shareholding of 5% for any one employee.
In terms of the rules of the EIS, grants will be made at the discretion of the Avikro Remuneration Committee (“Remcom”) on 1 July each year. Per the scheme rules 20% of the grants will be unconditional but the remaining 80% will be conditional on the achievement of performance targets set by the Remcom. There will be two vesting dates which will be on the second and fourth anniversary dates of the original grant date. Per the scheme rules 25% of the grants will vest on the first vesting date and 75% will vest on the second vesting date.
Details of the grants issued and outstanding at 30 June 2019 are as follows -

Grant date | Vesting date | Category | Grants outstanding
1 July 2014 | 30 June 2018 | Unconditional | 7 500 |
1 July 2014 | 30 June 2018 | Conditional | 30 000 |
1 July 2015 | 30 June 2019 | Unconditional | 15 000
1 July 2015 | 30 June 2019 | Conditional | 60 000
1 July 2017 | 30 June 2019 | Unconditional | 4 000 |
1 July 2017 | 30 June 2019 | Conditional | 14 500 |
30 May 2018 | 30 June 2019 | Unconditional | 750 |
30 May 2018 | 30 June 2019 | Conditional | 2 250 |
1 July 2017 | 30 June 2021 | Unconditional | 13 500 |
1 July 2017 | 30 June 2021 | Conditional | 48 000 |
30 May 2018 | 30 June 2021 | Unconditional | 3 000 |
30 May 2018 | 30 June 2021 | Conditional | 9 000 |
Total |  |  | 207 500 |

4

Avikro Industries Proprietary Limited
Directors’ report
for the year ended 30 June 2018 (continued)
Executive Share Scheme
At a special general meeting held on 24 March 2016, shareholders approved the issue of 414 139 ordinary shares to the Chief Executive Officer (207 069 shares), the Chief Operating Officer (165 656 shares) and the Chief Financial Officer (41 414 shares) who are all executive directors of the company.
Neither the issue nor the retention of the Executive Share Scheme (“ESS”) by the participants is linked to any performance criteria. The retention of the ESS shares is conditional upon the participant remaining in the full-time employ of the company for a 5 year period commencing on 1 January 2016 and ending on 31 December 2020. If the participants full-time employment by the company terminates prior to 31 December 2020, the participant shall forfeit all the shares issued to him irrespective of the date on which termination occurs.
The ESS shares have been issued without any monetary payment from the participants. The consideration to be paid by the participants is in the form of future services to the company. All beneficial interest in the ESS shares, including the right to receive any dividends shall vest with the participants from date of issue.
The chief financial officer retired 28 November 2017 and forfeited all of his 41 414 shares.
A new issue of 30 000 shares was approved on 1 January 2018 and the same rules apply as above.
In terms of section 40(5)(b) of the Companies Act the executive shares are being held in trust by an escrow agent.
Long Term Incentive Plan ("LTIP")
In the directors’ report for the year ended 30 June 2015 it was stated that no new awards would be made under the SARS and LTIP schemes which had been approved at the annual general meeting of shareholders held on 30 November 2007. However with the need to retain the services of certain key employees the remuneration committee has agreed to reintroduce the LTIP and has approved the allocation of a certain number of notional Avikro ordinary shares to these key employees.
The details of the notional shares granted are as follows -

| Number of awards
| 30 June 2018 |  | 30 June 2017
At beginning of year | 25 000 |  |  | 25 000 |
Options awarded | 5 000 |  |  | — |
Options forfeited | (5 000) |  |  | — |
At end of year | 25 000 |  | 25 000 |

25% of the notional shares will vest on 1 June 2019.
75% of the notional shares will vest on 1 June 2021.
The notional shares will be cash settled, based on the market value of the Avikro ordinary shares, on the vesting date.
Resignation from the company results in participants forfeiting their allocations.
Non-executive directors’ participation in the company's shares
No non-executive directors have any options over shares in the company.
5

Avikro Industries Proprietary Limited
Directors’ report
for the year ended 30 June 2018 (continued)
Directors and secretary
The names of the directors, their responsibilities and meeting attendance are recorded in the table below.
The details of the secretary are set out on page 7.

Name | Classification | Committee | Board | Audit | Risk | RemCo• | Social & ethics
GAM Ravazzotti | Chairman: Non-executive | Remuneration | 4/4 | — | — | 1/1 | —
LA Foxcroft | Chief executive officer | Risk and social & ethics | 4/4 | 2/2* | 1/1 | 1/1* | 2/2
T Molefakgotla | Chief operating officer | Risk | 4/4 | — | 1/1 | 1/1* | —
DR Alston# | Chief financial officer | Risk and social & ethics | 2/4 | 1/2* | — | — | 0/2
SD Jagoe ■ | Director: Independent non-executive | Audit | 3/4 | 2/2 | — | — | —
R Ligege | Director: Independent non-executive |  | 4/4 | — | — | — | —
EM Mafuna | Director: Independent non-executive | Remuneration | 4/4 | — | — | 1/1 | —
NS Nematswerani | Director: Independent non-executive | Audit and risk | 4/4 | 2/2 | 1/1 | — | —
ND Orleyn | Director: Independent non-executive | Remuneration and social & ethics | 4/4 | — | — | 1/1 | 2/2
LEV Ravazzotti Langenhoven | Director: Non-executive |  | 4/4 | — | — | — | —

# Retired on 28 November 2017
■ Lead independent director
* Attendance by invitation
• Remuneration committee
Treasury shares
National Avikro Industries South Africa Proprietary Limited, a wholly owned subsidiary of the company, holds Avikro’s ordinary shares. These shares will be held as treasury shares for issue to beneficiaries of the ESS.
The number of treasury shares held by National Avikro Industries South Africa Proprietary Limited at 30 June 2019 amounted to 465 640 shares (2018 - 830 281 shares). During the current year 662 500 treasury shares were issued to the participants in terms of the Equity Incentive Scheme and 297 859 shares were purchased back from the participants.
Events subsequent to reporting date
The Board has declared a final dividend of 400 cents per share on the 18 August 2018.
Directors’ interest in contracts
No material contracts involving directors exist, or were entered into, during the period under review.
Report on directors’ remuneration
In accordance with the requirements of the Companies Act of South Africa, a detailed report on directors’ remuneration appears in note 23.
6

Avikro Industries Proprietary Limited
Directors’ report
for the year ended 30 June 2018 (continued)
Borrowing powers
In terms of its Memorandum of Incorporation, the company has unlimited borrowing powers.
Litigation
There are no pending or threatened legal or arbitration proceedings which have had or may have a material effect on the financial position of the Group and company.
Auditors
Nolands Inc
Company secretary and registered office
The company secretary is E J Willis, whose business and postal address is -

Physical address - | Postal address -
3 Atherstone Bower | P O Box 2005
77 King Edward Road | Edenvale
Lombardy East | 1610
2090 |

Business address - | Postal address - | Registered address -
Farm 2 | P O Box 2247 | Farm 2
Old Potchefstroom Road | Vereeniging | Old Potchefstroom Road
Vereeniging | 1930 | Vereeniging
1939 |  | 1939

7

Avikro Industries Proprietary Limited
Audit Committee’s report
for the year ended 30 June 2018
Background
The committee’s operation is guided by a charter that is based on the Companies Act of South Africa and the principles set out in King III, and is approved by the Board.
Purpose
The purpose of the committee is to -
•assist the Board in discharging its duties relating to -
•safeguarding Group assets and ensuring the operation of adequate systems and controls; and
•preparing reports and financial statements in compliance with the applicable legal requirements and accounting standards;
•provide a forum for discussing business risk and control issues and for developing recommendations
for consideration by the Board;
•oversee the activities of external audit;
•consider the appropriateness of the experience and expertise of the Chief Financial Officer; and
•perform duties that are attributed to it by the Act.
Membership
During the course of the year the membership of the committee comprised the following independent non-executive directors -
•NS Nematswerani (chairman)
•SD Jagoe
External audit
The committee has satisfied itself through enquiry that the auditor of Avikro Industries Proprietary Limited is independent as defined by the Act.
The committee, in consultation with executive management, agreed to a provisional audit fee for the 2018 financial year. The fee is considered appropriate for the work that could reasonably have been foreseen at that time. The final adjusted fee will be agreed on completion of the audit. Audit fees are disclosed in note 2 to the financial statements.
Internal audit
Internal audits are conducted by the deputy factory managers who swap duties with one of their colleagues, in order to evaluate the status of the Group’s production facilities. This includes an assessment of internal controls around the inventory management, purchases and sales systems. In addition there is an evaluation of processes in the factory. The process is overseen by members of the finance department.
8

Avikro Industries Proprietary Limited
Audit Committee’s report
for the year ended 30 June 2018
(continued)
Financial management
The Audit Committee has satisfied itself that AM Aucamp has the appropriate expertise and knowledge to fulfil the role of Group Financial Manager.
Annual financial statements
The committee has tabled the annual financial statements for approval by the Board. The Board has subsequently approved the annual financial statements which will be open for discussion at the forthcoming annual general meeting.
___________________
NS Nematswerani
Chairman of the Audit Committee
4 October 2018
9

Independent Auditor’s Report
To the shareholders of Avikro Industries Proprietary Limited
Opinion
We have audited the consolidated and separate financial statements of Avikro Industries Proprietary Limited (the group and company) set out on pages 12 to 58 which comprise the statements of financial position as at 30 June 2018, and the statements of profit or loss and other comprehensive income, statements of changes in equity and statements of cash flows for the year then ended, and notes to the financial statements, including a summary of significant accounting policies.
In our opinion, the consolidated and separate financial statements present fairly, in all material respects, the consolidated and separate financial position of Avikro Industries Proprietary Limited as at 30 June 2018, and its consolidated and separate financial performance and consolidated and separate cash flows for the year then ended in accordance with International Financial Reporting Standards and the requirements of the Companies Act of South Africa.
Basis for opinion
We conducted our audit in accordance with International Standards on Auditing (ISAs). Our responsibilities under those standards are further described in the Auditor’s Responsibilities for the Audit of the Consolidated and Separate Financial Statements section of our report. We are independent of the group and the company in accordance with the Independent Regulatory Board for Auditors Code of Professional Conduct for Registered Auditors (IRBA Code) and other independence requirements applicable to performing audits of financial statements in South Africa. We have fulfilled our other ethical responsibilities in accordance with the IRBA Code in accordance with other ethical requirements applicable to performing audits in South Africa. The IRBA Code is consistent with the International Ethics Standards Board for Accountants Code of Ethics for Professional Accountants (Parts A and B). We believe that the audit evidence we have obtained is sufficient and appropriate to provide a basis for our opinion.
Other Information
The directors are responsible for the other information. The other information comprises the Directors’ Report as required by the Companies Act of South Africa, the Audit Committee’s report, the Directors’ responsibility statement and Certificate of the Company Secretary. The other information does not include the consolidated and separate financial statements and our auditor’s report thereon.
Our opinion on the consolidated and separate financial statements does not cover the other information and we do not express an audit opinion or any form of assurance conclusion thereon.
In connection with our audit of the consolidated and separate financial statements, our responsibility is to read the other information and, in doing so, consider whether the other information is materially inconsistent with the consolidated and separate financial statements or our knowledge obtained in the audit, or otherwise appears to be materially misstated. If, based on the work we have performed, we conclude that there is a material misstatement of this other information, we are required to report that fact. We have nothing to report in this regards.
Responsibilities of the Directors for the Consolidated and Separate Financial Statements
The directors are responsible for the preparation and fair presentation of the consolidated and separate financial statements in accordance with International Financial Reporting Standards and the requirements of the Companies Act of South Africa, and for such internal control as the directors determine is necessary to enable the preparation of consolidated and separate financial statements that are free from material misstatement, whether due to fraud or error.
In preparing the consolidated and separate financial statements, the directors are responsible for assessing the group’s and the company’s ability to continue as a going concern, disclosing, as applicable, matters relating to going concern and using the going concern basis of accounting unless the directors either intend to liquidate the group and/or company or to cease operations, or have no realistic alternative but to do so.
Auditor’s Responsibilities for the Audit of the Consolidated and Separate Financial Statements
Our objectives are to obtain reasonable assurance about the consolidated and separate financial statements as a whole are free from material misstatement, whether due to fraud or error, and to issue an auditor’s report that includes our opinion. Reasonable assurance is a high level of assurance, but is not a guarantee that an audit conducted in accordance with ISAs will always detect a material misstatement when it exists. Misstatements can arise from fraud or error and are considered material if, individually or in the aggregate, they could reasonably be expected to influence the economic decisions of users taken on the basis of these consolidated and separate financial statements.
As part of an audit in accordance with ISAs, we exercise professional judgement and maintain professional scepticism throughout the audit, We also:
10

- Identify and assess the risks of material misstatement of the consolidated and separate financial statements, whether due to fraud or error, design and perform audit procedures responsive to those risks, and obtain audit evidence that is sufficient and appropriate to provide a basis for our opinion. The risk of not detecting a material misstatement resulting from fraud is higher than for one resulting from error, as fraud may involve collusion, forgery, intentional omissions, misrepresentations, or the override of internal control.
- Obtain an understanding of internal control relevant to the audit in order to design audit procedures that are appropriate in the circumstances, but not for the purpose of expressing an opinion on the effectiveness of the company’s internal control.
- Evaluate the appropriateness of accounting policies used and the reasonableness of accounting estimates and related disclosures made by the directors.
- Conclude on the appropriateness of the directors’ use of the going concern basis of accounting and based on the audit evidence obtained, whether a material uncertainty exists related to events or conditions that may cast significant doubt on the group’s and the company’s ability to continue as a going concern. If we conclude that a material uncertainty exists, we are required to draw attention in our auditor’s report to the related disclosures in the consolidated and separate financial statements or, if such disclosures are inadequate, to modify our opinion. Our conclusions are based on the audit evidence obtained up to the date of our auditor’s report. However, future events or conditions may cause the group and/or the company to cease to continue as a going concern.
- Evaluate the overall presentation, structure and content of the consolidated and separate financial statements, including the disclosures, and whether the consolidated and separate financial statements represent the underlying transactions and events in a manner that achieves fair presentation.
- Obtain sufficient appropriate audit evidence regarding the financial information of the entities or business activities within the group to express an opinion on the consolidated financial statements. We are responsible for the direction, supervision and performance of the group audit. We remain solely responsible for our audit opinion.
We communicate with the directors regarding, among other matters, the planned scope and timing of the audit and significant audit findings, including any significant deficiencies in internal control that we identify during our audit.
asd
Nolands Inc.
Per: Allan Mundell
Chartered Accountant (SA)
Director
Registered Auditor
Auditor Number 701
4 October 2018
11

Avikro Industries Proprietary Limited
Statements of profit or loss and other comprehensive income
for the year ended 30 June 2018

|  |  | Group |  |  | Company |
|  |  | 2019 |  |  | 2018 |  |  | 2019 |  |  | 2018 |
| Notes |  | R000's |  |  | R000's |  |  | R000's |  |  | R000's |
Revenue | 1 |  | 3 343 674 |  |  |  | 3 039 422 |  |  |  | 585 |  |  |  | 280 493 |  |
Cost of sales |  |  | (2 401 434) |  |  |  | (2 195 809) |  |  |  | 0 |  |  |  | 0 |  |
Gross profit |  |  | 942 240 |  |  |  | 843 613 |  |  |  | 585 |  |  |  | 280 493 |  |
Operating expenses |  |  | (384 389) |  |  |  | (329 362) |  |  |  | (500) |  |  |  | (665) |  |
Operating profit/(loss) | 2 |  | 557 851 |  |  |  | 514 251 |  |  |  | 85 |  |  |  | 279 828 |  |
Finance income | 3 |  | 25 978 |  |  |  | 26 212 |  |  |  | 3 043 |  |  |  | 1 |  |
Finance expense | 4 |  | (85) |  |  |  | (16) |  |  |  | (8) |  |  |  | (20 475) |  |
Share of profit of equity accounted investee, net of taxation | 8 |  | 15 233 |  |  |  | 13 440 |  |  |  |  |  |  |  |
Profit before taxation |  |  | 598 977 |  |  |  | 553 887 |  |  |  | 3 120 |  |  |  | 259 354 |  |
Taxation | 5 |  | (127 026) |  |  |  | (152 279) |  |  |  | (800) |  |  |  | 5 417 |  |
Profit for the year |  |  | 471 951 |  |  |  | 401 608 |  |  |  | 2 320 |  |  |  | 264 771 |  |
Other comprehensive income |  |  |  |  |  |  |  |  |  |  |  |  |
Items that may subsequently be reclassified to profit or loss: |  |  |  |  |  |  |  |  |  |  |  |  |
Net foreign currency translation differences from foreign operations |  |  | (7 027) |  |  |  | (33 202) |  |  |  |  |  |  |  |
Foreign currency translation differences from foreign operations |  |  | 5 577 |  |  |  | (35 298) |  |  |  |  |  |  |  |
Realisation of the foreign currency translation reserve |  |  | (11 752) |  |  |  | (5 046) |  |  |  |  |  |  |  |
Deferred taxation thereon |  |  | (852) |  |  |  | 7 142 |  |  |  |  |  |  |  |
Total comprehensive income for the year |  |  | 464 924 |  |  |  | 368 406 |  |  |  | 2 320 |  |  |  | 264 771 |  |
Profit attributable to |  |  | 471 951 |  |  |  | 401 608 |  |  |  | 2 320 |  |  |  | 264 771 |  |
Owners of company |  |  | 471 160 |  |  |  | 400 649 |  |  |  | 2 320 |  |  |  | 264 771 |  |
Non-controlling interest | 9 |  | 791 |  |  |  | 959 |  |  |  |  |  |  |  |
Total comprehensive income attributable to |  |  | 464 924 |  |  |  | 368 406 |  |  |  | 2 320 |  |  |  | 264 771 |  |
Owners of company |  |  | 463 316 |  |  |  | 367 907 |  |  |  | 2 320 |  |  |  | 264 771 |  |
Non-controlling interest | 9 |  | 1 608 |  |  |  | 499 |  |  |  |  |  |  |  |

12

Avikro Industries Proprietary Limited
Statements of financial position
as at 30 June 2018

|  | Group |  |  | Company |
|  | 2019 |  |  | 2018 |  |  | 2019 |  |  | 2018 |
| Notes | R000's |  |  | R000's |  |  | R000's |  |  | R000's |
Assets |  |  |  |  |  |  |  |  |  |  |  |
Non-current assets |  | 1 626 989 |  |  |  | 1 456 992 |  |  |  | 698 414 |  |  |  | 690 047 |  |
Property, plant and equipment | 6 | 1 549 798 |  |  |  | 1 392 886 |  |  |  | 4 263 |  |  |  | 4 263 |  |
Goodwill | 7 | 4 520 |  |  |  | 4 520 |  |  |  |  |  |  |  |
Equity-accounted investee | 8 | 70 569 |  |  |  | 57 957 |  |  |  |  |  |  |  |
Deferred taxation assets | 16 | 2 102 |  |  |  | 1 629 |  |  |  | 0 |  |  |  | 0 |  |
Investment in subsidiaries | 9 |  |  |  |  |  |  | 694 151 |  |  |  | 685 784 |  |
Current assets |  | 1 130 800 |  |  |  | 993 246 |  |  |  | 6 778 |  |  |  | 6 316 |  |
Inventories | 10 | 279 973 |  |  |  | 234 371 |  |  |  | 0 |  |  |  | 0 |  |
Trade and other receivables | 11 | 634 434 |  |  |  | 504 502 |  |  |  | 6 261 |  |  |  | 6 034 |  |
Taxation receivable |  | 2 674 |  |  |  | 2 511 |  |  |  |  |  |  |  |
Cash and cash equivalents | 12 | 213 719 |  |  |  | 251 862 |  |  |  | 517 |  |  |  | 282 |  |
Total assets |  | 2 757 789 |  |  |  | 2 450 238 |  |  |  | 705 192 |  |  |  | 696 363 |  |
Equity and liabilities |  |  |  |  |  |  |  |  |  |  |  |
Capital and reserves attributable to equity holders of the company |  | 2 231 485 |  |  |  | 2 013 534 |  |  |  | 122 168 |  |  |  | 295 181 |  |
Share capital | 13 | 64 816 |  |  |  | 64 816 |  |  |  | 64 816 |  |  |  | 64 816 |  |
Treasury shares | 14 | (101 827) |  |  |  | (98 672) |  |  |  |  |  |  |  |
Share-based payment reserve |  | 37 344 |  |  |  | 37 344 |  |  |  | 37 344 |  |  |  | 37 344 |  |
Share awards reserve |  | 61 913 |  |  |  | 98 821 |  |  |  | 121 572 |  |  |  | 95 112 |  |
Foreign currency translation reserve |  | 132 025 |  |  |  | 139 870 |  |  |  |  |  |  |  |
Retained earnings |  | 2 037 214 |  |  |  | 1 771 355 |  |  |  | (101 564) |  |  |  | 97 909 |  |
Non-controlling interest | 9 | 5 932 |  |  |  | 5 372 |  |  |  |  |  |  |  |
Total equity |  | 2 237 417 |  |  |  | 2 018 906 |  |  |  | 122 168 |  |  |  | 295 181 |  |
Non-current liabilities |  | 101 263 |  |  |  | 81 328 |  |  |  | 14 257 |  |  |  | 16 696 |  |
Shareholders’ loans | 15 | 3 314 |  |  |  | 3 808 |  |  |  |  |  |  |  |
Deferred taxation liabilities | 16 | 97 949 |  |  |  | 77 520 |  |  |  | 14 257 |  |  |  | 16 696 |  |
Current liabilities |  | 419 109 |  |  |  | 350 004 |  |  |  | 568 767 |  |  |  | 384 486 |  |
Trade and other payables | 17 | 381 183 |  |  |  | 322 232 |  |  |  | 0 |  |  |  | 0 |  |
Taxation payable |  | 17 156 |  |  |  | 6 685 |  |  |  | 546 |  |  |  | 1 125 |  |
Provision for rehabilitation | 18 | 20 460 |  |  |  | 20 777 |  |  |  | 0 |  |  |  | 0 |  |
Shareholders for dividends |  | 310 |  |  |  | 310 |  |  |  | 310 |  |  |  | 310 |  |
Loans from subsidiaries | 9 |  |  |  |  |  |  | 567 911 |  |  |  | 383 051 |  |
Total liabilities |  | 520 372 |  |  |  | 431 332 |  |  |  | 583 024 |  |  |  | 401 182 |  |
Total equity and liabilities |  | 2 757 789 |  |  |  | 2 450 238 |  |  |  | 705 192 |  |  |  | 696 363 |  |

13

Avikro Industries Proprietary Limited
Statements of changes in equity
for the year ended 30 June 2018

| Attributable to owners of the company |  |  |
Group | Share capital | Treasury shares | Share-based payment reserve | Share awards reserve | Foreign currency translation reserve | Retained earnings | Total | Non-controlling interest | Total |
| R000's | R000's | R000's | R000's | R000's | R000's | R000's | R000's | R000's |
Balance at 30 June 2017 | 64 816 |  | (98 749) |  | 47 212 |  | 62 549 |  | 172 074 |  | 1 562 606 |  | 1 810 508 |  | 3 074 |  | 1 813 582 |  |
Profit for the year |  |  |  |  |  | 400 649 |  | 400 649 |  | 959 |  | 401 608 |  |
Other comprehensive income |  |  |  | (326) |  | (32 416) |  |  | (32 742) |  | (460) |  | (33 202) |  |
Movement in translation of foreign subsidiaries |  |  |  | (326) |  | (14 053) |  |  | (14 379) |  | (460) |  | (14 839) |  |
Movement in translation of long-term amounts owing by foreign subsidiaries |  |  |  |  | (20 459) |  |  | (20 459) |  |  | (20 459) |  |
Realisation of the foreign currency translation reserve due to part payment of the long-term loan |  |  |  |  | (5 046) |  |  | (5 046) |  |  | (5 046) |  |
Movement in deferred taxation relating to movement in translation of long-term amounts |  |  |  |  | 7 142 |  |  | 7 142 |  |  | 7 142 |  |
Total comprehensive income for the year |  |  |  | (326) |  | (32 416) |  | 400 649 |  | 367 907 |  | 499 |  | 368 406 |  |
Transaction with owners recorded directly in equity |  |  |  |  |  |  |  |  |  |
Shares issued to share participants |  | 2 552 |  |  |  |  |  | 2 552 |  |  | 2 552 |  |
Re-purchased from share participants |  | (2 475) |  |  |  |  |  | (2 475) |  |  | (2 475) |  |
Equity-settled share-based payments |  |  |  | 42 122 |  |  |  | 42 122 |  |  | 42 122 |  |
Payments made during the year |  |  |  | (5 524) |  |  | (3 979) |  | (9 503) |  |  | (9 503) |  |
Transfer between foreign currency translation reserve and minority interest |  |  |  |  | 212 |  |  | 212 |  | (212) |  | 0 |  |
Dissolution of BEE Trust |  |  | (9 868) |  |  |  | (58 652) |  | (68 520) |  |  | (68 520) |  |
Dividends paid |  |  |  |  |  | (134 915) |  | (134 915) |  |  | (134 915) |  |
Dividends received by subsidiary |  |  |  |  |  | 5 646 |  | 5 646 |  |  | 5 646 |  |
Transactions from non-controlling interest |  |  |  |  |  |  |  | 2 011 |  | 2 011 |  |
Total transactions with owners for the year |  | 77 |  | (9 868) |  | 36 598 |  | 212 |  | (191 900) |  | (164 881) |  | 1 799 |  | (163 082) |  |
Balance at 30 June 2018 | 64 816 |  | (98 672) |  | 37 344 |  | 98 821 |  | 139 870 |  | 1 771 355 |  | 2 013 534 |  | 5 372 |  | 2 018 906 |  |

14

Avikro Industries Proprietary Limited
Statements of changes in equity
for the year ended 30 June 2018 (continued)

| Attributable to owners of the company |  |
Group | Share capital | Treasury shares | Share-based payment reserve | Share awards reserve | Foreign currency translation reserve | Retained earnings | Total | Non-controlling interest | Total |
| R000's | R000's | R000's | R000's | R000's | R000's | R000's | R000's | R000's |
Balance at 30 June 2018 | 64 816 |  | (98 672) |  | 37 344 |  | 98 821 |  | 139 870 |  | 1 771 355 |  | 2 013 534 |  | 5 372 |  | 2 018 906 |  |
Profit for the year |  |  |  |  |  | 471 160 |  | 471 160 |  | 791 |  | 471 951 |  |
Other comprehensive income |  |  |  |  | (7 844) |  |  | (7 844) |  | 817 |  | (7 027) |  |
Movement in translation of foreign subsidiaries |  |  |  |  | 1 717 |  |  | 1 717 |  | 817 |  | 2 534 |  |
Movement in translation of long-term amounts owing by foreign subsidiaries |  |  |  |  | 3 043 |  |  | 3 043 |  |  | 3 043 |  |
Realisation of the foreign currency translation reserve due to part payment of the long-term loan |  |  |  |  | (11 752) |  |  | (11 752) |  |  | (11 752) |  |
Movement in deferred taxation relating to movement in translation of long-term amounts |  |  |  |  | (852) |  |  | (852) |  |  | (852) |  |
Total comprehensive income for the year |  |  |  |  | (7 844) |  | 471 160 |  | 463 316 |  | 1 608 |  | 464 924 |  |
Transaction with owners recorded directly in equity |  |  |  |  |  |  |  |  |  |
Shares issued to share participants |  | 68 766 |  |  |  |  |  | 68 766 |  |  | 68 766 |  |
Re-purchased from share participants |  | (71 921) |  |  |  |  |  | (71 921) |  |  | (71 921) |  |
Equity-settled share-based payments |  |  |  | 20 065 |  |  |  | 20 065 |  |  | 20 065 |  |
Transfer between reserves |  |  |  | (56 973) |  |  | 56 973 |  | 0 |  |  | 0 |  |
Treasury shares issued |  |  |  |  |  | (65 139) |  | (65 139) |  |  | (65 139) |  |
Dividends paid |  |  |  |  |  | (202 013) |  | (202 013) |  |  | (202 013) |  |
Dividends received by subsidiary |  |  |  |  |  | 4 877 |  | 4 877 |  |  | 4 877 |  |
Transactions to non-controlling interest |  |  |  |  |  |  |  | (1 048) |  | (1 048) |  |
Total transactions with owners for the year |  | (3 155) |  | 0 |  | (36 908) |  | 0 |  | (205 302) |  | (245 365) |  | (1 048) |  | (246 413) |  |
Change in equity | 0 | (3 155) |  | 0 |  | (36 908) |  | (7 844) |  | 265 858 |  | 217 951 |  | 560 |  | 218 511 |  |
Balance at 30 June 2019 | 64 816 |  | (101 827) |  | 37 344 |  | 61 913 |  | 132 026 |  | 2 037 213 |  | 2 231 485 |  | 5 932 |  | 2 237 417 |  |

15

Avikro Industries Proprietary Limited
Statements of changes in equity
for the year ended 30 June 2018 (continued)

Company | Share capital | Share awards reserve | Share-based payment reserve | Retained earnings | Total |
| R000's | R000's | R000's | R000's | R000's |
Balance at 30 June 2017 | 64 816 |  | 58 978 |  | 47 212 |  | 26 558 |  | 197 564 |  |
Total comprehensive income for the year |  |  |  | 264 771 |  | 264 771 |  |
Transactions with owners recorded directly in equity |  |  |  |  |  |
Equity-settled share-based payments |  | 38 957 |  |  |  | 38 957 |  |
Payments made during the year |  | (2 823) |  |  |  | (2 823) |  |
Dissolution of BEE Trust |  |  | (9 868) |  | (58 652) |  | (68 520) |  |
Dividends paid |  |  |  | (134 768) |  | (134 768) |  |
Total transactions with owners for the year |  | 36 134 |  | (9 868) |  | (193 420) |  | (167 154) |  |
Balance at 30 June 2018 | 64 816 |  | 95 112 |  | 37 344 |  | 97 909 |  | 295 181 |  |
Total comprehensive income for the year |  |  |  | 2 320 |  | 2 320 |  |
Transactions with owners recorded directly in equity |  |  |  |  |  |
Equity-settled share-based payments |  | 26 460 |  |  |  | 26 460 |  |
Dividends paid |  |  |  | (201 793) |  | (201 793) |  |
Total transactions with owners for the year |  | 26 460 |  | 0 |  | (201 793) |  | (175 333) |  |
Balance at 30 June 2019 | 64 816 |  | 121 572 |  | 37 344 |  | (101 564) |  | 122 168 |  |

16

Avikro Industries Proprietary Limited
Statements of cash flows
for the year ended 30 June 2018

|  | Group |  | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
| Notes | R000's |  | R000's |  | R000's |  | R000's
Cash generated/(utilised) by operations | 21.1 | 613 106 |  |  | 558 917 |  |  | 2 901 |  |  | (128) |
Finance income |  | 25 978 |  |  | 25 816 |  |  | 0 |  |  | 0 |
Finance expense |  | (8) |  |  | 0 |  |  | 0 |  |  | 0 |
Dividends received |  | 4 402 |  |  | 4 309 |  |  | 0 |  |  | 0 |
Dividends paid | 21.2 | (197 136) |  |  | (129 269) |  |  | 0 |  |  | 0 |
Taxation paid | 21.3 | (97 692) |  |  | (125 175) |  |  | (3 826) |  |  | (1 940) |
Net cash inflow/(outflow) from operating activities |  | 348 650 |  |  | 334 598 |  |  | (925) |  |  | (2 068) |
Cash flows from investing activities |  |  |  |  |  |  |  |
Additions to property, plant and equipment to expand operations |  | (314 501) |  |  | (373 682) |  |  | 0 |  |  |
Proceeds from disposal of property, plant and equipment |  | 2 952 |  |  | 2 675 |  |  | 0 |  |  |
Increase in investment in associated company |  | (1 781) |  |  | 0 |  |  |  |  |
Increase in loans to subsidiaries |  |  |  |  |  | 8 367 |  |  | 9 145 |
Net cash (outflow)/inflow from investing activities |  | (313 330) |  |  | (371 007) |  |  | 8 367 |  |  | 9 145 |
Cash flows from financing activities |  |  |  |  |  |  |  |
Shareholders’ loans repaid |  | (494) |  |  | (503) |  |  | 0 |  |  | 0 |
Share-based payments made |  | 0 |  |  | (9 503) |  |  | 0 |  |  | (2 823) |
Shares re-purchased from share participants |  | (71 921) |  |  | (2 475) |  |  | 0 |  |  | 0 |
Transactions (from)/to non-controlling interest |  | (1 048) |  |  | 2 011 |  |  | 0 |  |  | 0 |
Dissolution of BEE Trust |  | 0 |  |  | (68 520) |  |  | 0 |  |  | 0 |
Decrease in loans from subsidiaries |  |  |  |  |  | (7 207) |  |  | (4 144) |
Net cash outflow from financing activities |  | (73 463) |  |  | (78 990) |  |  | (7 207) |  |  | (6 967) |
Movement in cash and cash equivalents |  | (38 143) |  |  | (115 399) |  |  | 235 |  |  | 110 |
Cash and cash equivalents at beginning of year |  | 251 862 |  |  | 367 261 |  |  | 282 |  |  | 172 |
Cash and cash equivalents at end of year |  | 213 719 |  |  | 251 862 |  |  | 517 |  |  | 282 |

17

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2018
Reporting entity
Avikro Industries Proprietary Limited (the “Company”) is a company domiciled in South Africa. The address of the Company’s registered office is Farm 2, Old Potchefstroom Road, Vereeniging. These group financial statements comprise of Avikro Industries Proprietary Limited and its subsidiaries (collectively the “Group” and individually as “Group companies”) and the Group’s interest in associates.
Where reference is made to the Group in the accounting policies, it should be interpreted as referring to include the Company, unless otherwise noted.
The Group is involved in the manufacture and sale of Avikro and porcelain floor and wall tiles, vitreous china sanitaryware and acrylic bathroomware.
The principle accounting policies adopted in the preparation of the financial statements are set out below.
Statement of compliance
The Group financial statements and financial statements have been prepared in accordance with International Financial Reporting Standards (“IFRS”) and the requirements of the Companies Act of South Africa.
The Group financial statements and financial statements were authorised for issue by the Directors on 4 October 2018.
Basis of measurement
The Group financial statements and the financial statements have been prepared on the historical cost basis, except for share-based payment arrangements which are measured at their fair value.
Functional and presentation currency
These Group financial statements and financial statements are presented in South African Rands (“R”) which is the Company’s functional currency. All financial information presented in Rands has been rounded to the nearest thousand (“R000”), except where otherwise indicated.
Use of estimates and judgements
In preparing these Group financial statements management has made judgements, estimates and assumptions that affect the application of the Group’s accounting policies and the reported amounts of assets, liabilities, income and expenses. Actual results may differ from these estimates.
Estimates and underlying assumptions are reviewed on an ongoing basis. Revisions to accounting estimates are recognised in the period in which the estimates are revised and in any future periods affected.
Information about other areas of estimation and critical judgements in applying accounting policies that have the most significant effect on the amounts recognised in the financial statements are described in the following notes -
Note 2 - Measurement of share based payment transactions
Note 6 - Useful lives and residual values of property, plant and equipment
Note 18 - Provision for rehabilitation of clay quarries
Changes in accounting policies
The accounting policies set out below have been applied consistently to all years presented in these Group financial statements and have been applied consistently by all Group companies during the financial year. There were no new standards or amendments that were implemented during the year that had a material impact on the Group financial statements.
18

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
Basis of consolidation
Non-controlling interest
Non-controlling interest is measured at its proportionate share of the acquiree’s identifiable net assets at the date of acquisition. No adjustments are made to goodwill and no gain or loss is recognised in profit or loss. Changes in the Group’s interest in a subsidiary that does not result in a loss of control is accounted for as an equity transaction.
Investment in subsidiaries
Subsidiaries are entities controlled by the Group. The Group controls a company when it is exposed to, or has rights to, variable returns from its involvement with the company and has the ability to affect those returns through the use of its power over the company.
The financial results of subsidiaries are included in the Group financial statements from the date that control commences until the date that control ceases.
The accounting policies of the subsidiaries have been changed when necessary to align with the policies adopted by the Group.
In the separate annual financial statements of the Company, the investment in subsidiaries is measured at cost, less impairment losses.
Goodwill
Goodwill arising on business combinations is recognised at cost less accumulated impairment losses.
Goodwill is tested at each reporting date for impairment.
Equity-accounted investee
Equity-accounted investees are those companies in which the Group has significant influence but not control over the financial and operating policies.
Equity-accounted investees are accounted for using the equity method. They are initially recognised at cost, which includes transaction costs.
Subsequent to initial recognition, the Group financial statements include the Group’s share of the profit or loss until the date on which significant influence ceases.
Transactions eliminated on consolidation
Intra-group balances and transactions, and any unrealised income and expenses arising from the intra-group transactions, are eliminated on consolidation. Unrealised gains arising from transactions with equity-accounted investees are eliminated against the investment to the extent of the Group’s interest in the investee.
Unrealised losses are eliminated in the same way as unrealised gains, but only to the extent that there is no evidence of impairment.
Foreign currency transactions
Transactions in foreign currencies are translated to the respective functional currencies of Group entities at exchange rates at the dates of the transactions.
Monetary assets and liabilities denominated in foreign currencies at the reporting date are translated to the functional currency at the exchange rate at that date. Foreign exchange gains and losses resulting from translation and settlement of monetary assets and liabilities are recognised in profit or loss.
Non-monetary assets and liabilities that are measured at fair value in a foreign currency are translated to the functional currency at the exchange rate at the date that the fair value was determined.
19

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
Foreign currency transactions (continued)
Non-monetary items that are measured based on historical cost in a foreign currency are translated using the exchange rate at the date of the transaction.
Foreign currency gains and losses are reported on a net basis in either finance income or finance expense depending on whether the foreign currency movements are in a net gain or net loss position.
Foreign operations
The assets and liabilities of foreign operations, including goodwill and fair value adjustments arising on acquisition, are translated to Rands at exchange rates at the reporting date.
The income and expenses of the foreign operations are translated to Rand at exchange rates at the date of the transactions.
When the settlement of a monetary item receivable or payable to a foreign operation is neither planned nor likely in the foreseeable future, foreign currency gains and losses arising from such item are considered to form part of a net investment in a foreign operation.
In the Group financial statements differences arising from translation of the net investment in a foreign operation are recognised as other comprehensive income and are presented within equity in the foreign currency translation reserve. However, if the foreign operation is a non-wholly owned subsidiary, then the relevant proportion of the translation difference is allocated to non-controlling interests.
When the foreign operation is disposed of, such that control is lost, the cumulative amount in the translation reserve related to that foreign operation is reclassified to profit or loss as part of a gain or loss on disposal.
When the Group disposes of only part of its interest in a subsidiary that includes a foreign operation while retaining control, the relevant proportion of the cumulative amount is reattributed to non-controlling interests. In any other partial disposal of a foreign operation, the Group reclassifies to profit or loss only the proportionate share of the cumulative amount of the foreign exchange differences recognised in other comprehensive income.
Exchange rates utilised to convert financial information are as follows -

| 2018 | 2017
| Weighted average rate for the year | Closing rate | Weighted average rate for the year | Closing rate
ZAR : AUD | 9,98 : 1 | 10,13 : 1 | 10,27 : 1 | 10,02 : 1
ZAR : EUR | 15,34 : 1 | 15,96 : 1 | 14,85 : 1 | 14, 90 : 1
ZAR : USD | 12,87 : 1 | 13,71 : 1 | 13,61 : 1 | 13,03 : 1
ZAR : GBP | 17,31 : 1 | 17,98 : 1 | 17,28 : 1 | 16, 95 : 1

Segmental reporting
Segment results that are reported to the Chief Executive Officer (the chief operating decision maker) include items directly attributable to a segment as well as those that can be allocated on a reasonable basis.
20

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
Revenue
Revenue from the sale of goods in the course of ordinary activities is measured at the fair value of the consideration received or receivable, net of returns, trade discounts and volume rebates. Revenue is recognised when significant risks and rewards of ownership have been transferred to the customer, recovery of the consideration is probable, the associated costs and possible return of goods can be estimated reliably and the Group no longer retains continuing managerial involvement to the degree associated with ownership or effective control. If it is probable that the discounts will be granted and the amount can be measured reliably, then the discount is recognised as a reduction of revenue as the sales are recognised.
Dividend income received from subsidiary companies is recognised in profit or loss on the date on which the Company's right to receive payment is established.
Leases
Determining whether an arrangement contains a lease:
At inception of an arrangement, the Group determines whether the arrangement is or contains a lease. At inception or on reassessment of an arrangement that contains a lease, the Group separates payments and other considerations required by the arrangement into those for the lease and those for other elements on the basis of their relative fair values.
Operating leases
Leases of assets under which all the risks and benefits of ownership are effectively retained by the lessor are classified as operating leases. Payments made under operating leases are recognised in profit or loss on a straight-line basis over the term of the lease.
Finance income and finance expense
The Groups finance income and finance expense include:
•Interest income;
•Interest expense;
•Dividend income (other than from subsidiary companies); and
•The net foreign exchange gain or loss on financial assets and financial liabilities.
Interest income and interest expense is recognised as it accrues in profit or loss, using the effective interest method. Dividend income is recognised in profit or loss on the date on which the Group's right to receive payment is established.
Foreign currency gains and losses on financial assets and financial liabilities are reported on a net basis as either finance income or finance expense depending on whether foreign currency movements are in a net gain or net loss position.
Taxation
Income taxation comprises current and deferred taxation. Current taxation and deferred taxation is recognised in profit or loss except to the extent that it relates to items recognised directly in equity or in other comprehensive income in which case it is recognised in equity or in other comprehensive income respectively.
Current taxation
Current taxation is the expected taxation payable on the taxable income for the year, using the taxation rates enacted or substantively enacted at the reporting date, and any adjustment of taxation payable in respect of previous years.
21

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
Deferred taxation
Deferred taxation is recognised in respect of temporary differences between the carrying amounts of assets and liabilities for financial reporting purposes and amounts used for taxation purposes.
Taxation (continued)
Deferred taxation (continued)
Deferred taxation is not provided on temporary differences relating to:
•Taxable temporary differences arising on the initial recognition of goodwill;
•Temporary differences on the initial recognition of assets and liabilities in a transaction that is not a business combination and that affects neither accounting nor taxable profit or loss; and
•Temporary differences related to investments in subsidiaries and associates to the extent that the Group is able to control the timing of the reversal of the temporary differences and it is probable that they will not reverse in the foreseeable future.
The measurement of deferred taxation reflects the taxation consequences that would follow the manner in which the Group expects, at the end of the reporting period, to recover or settle the carrying amount of its assets and liabilities.
Deferred taxation is measured at the taxation rates that are expected to be applied to temporary differences when they reverse, using taxation rates enacted or substantively enacted at the reporting date. In the event that the applicable taxation rate(s) are changed from those applied in the comparative financial reporting year, the opening balance of the deferred taxation asset or liability shall be adjusted for the change in the taxation rates.
Deferred taxation assets and liabilities are offset, if there is a legally enforceable right to offset current taxation liabilities and assets, and they relate to taxes levied by the same taxation authority on the same taxable entity, or on different taxation entities, but they intend to settle current taxation liabilities and assets on a net basis or their taxation assets and liabilities will be realised simultaneously.
A deferred taxation asset is recognised for unused taxation losses, taxation credits and deductible temporary differences to the extent that it is probable that future taxable profits will be available against which they can be utilised. Deferred taxation assets are reviewed at each reporting date and are reduced to the extent that it is no longer probable that the related taxation benefit will be realised.
Unrecognised deferred taxation assets are reassessed at each reporting date and recognised to the extent that it has become probable that future taxable profits will be available against which they can be used.
Dividends withholding taxation
The Group withholds dividends taxation on behalf of its shareholders at a standard rate of 20% on dividends declared. Amounts withheld are not recognised as part of the Group’s taxation expense but rather as part of the dividend paid recognised directly in equity.
Where withholding taxation is withheld on dividends received, the dividend is recognised at the gross amount with the related withholdings taxation recognised as part of taxation expense unless it is otherwise reimbursable in which case it is recognised as an asset.
Property, plant and equipment
Recognition and measurement
Items of property, plant and equipment are initially measured at cost and subsequently at cost, less accumulated depreciation and impairment losses.
Cost includes expenditure that is directly attributable to the acquisition of the asset. The cost of self-constructed assets include the following -
22

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
•the cost of materials and direct labour; and
•any other costs directly attributable to bringing the assets to a working condition for their intended use.
Property, plant and equipment (continued)
Recognition and measurement (continued)
Costs capitalised for work-in-progress in respect of activities to develop, expand or enhance items of property, plant and equipment are classified as part of capital work-in-progress.
The carrying amount of property, plant and equipment is derecognised on disposal or when no future economic benefits are expected from its use. Gains and losses on disposal of an item of property, plant and equipment are determined by comparing the proceeds from disposal with the carrying amount of the property, plant and equipment and are recognised in profit or loss.
When parts of an item of property, plant and equipment have different useful lives, they are accounted for as separate items (major components) of property, plant and equipment.
Subsequent costs
Subsequent expenditure is capitalised only if it is probable that the future economic benefits associated with the expenditure will flow to the Group. Any remaining carrying amount of the replaced part is written off to profit or loss. The costs of the day to day servicing of property, plant and equipment are recognised in profit or loss as incurred.
Depreciation
Items of property, plant and equipment are depreciated from the date that they are available for use, or in respect of self-constructed assets, from the date that the asset is ready for use.
Depreciation is calculated to write off the cost of items of property, plant and equipment less their estimated residual values using the straight-line basis over their estimated useful lives. Depreciation is recognised in profit or loss. Land and capital work-in-progress is not depreciated.
The current and comparative year’s estimated useful lives of significant items of property, plant and equipment are as follows -

Freehold buildings | 10 to 20 years
Plant and machinery | 5 to 15 years
Motor vehicles | 5 years
Office equipment | 3 to 5 years

Computer equipment, computer software and furniture and fittings are included as part of office equipment and are depreciated over 3 to 5 years.
Depreciation methods, useful lives and residual values are reviewed at each reporting date and adjusted if appropriate.
Financial instruments
The Group classifies its non-derivative financial instruments as loans and receivables and other financial liabilities.
The classification is dependent on the purpose for which the financial instrument is acquired. Management determines the classification of its financial assets and financial liabilities at the time of the initial recognition.
Non-derivative financial assets and financial liabilities - recognition and derecognition
23

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
The Group initially recognises loans and receivables on the date that they are originated. All other financial assets and financial liabilities are recognised initially on the trade date, which is the date that the Group becomes a party to the contractual provisions of the instrument.
Financial instruments (continued)
Non-derivative financial assets and financial liabilities - recognition and derecognition (continued)
The Group derecognises a financial asset when the contractual right to the cash flows from the asset expire, or it transfers the rights to receive the contractual cash flows in a transaction in which substantially all the risk and rewards of ownership of the financial asset are transferred. Any interest in such transferred financial assets that is created or retained by the Group is recognised as a separate asset or liability.
The Group derecognises a financial liability when its contractual obligations are discharged or cancelled or expire.
Non-derivative financial assets - measurement
Loans and receivables are financial assets with fixed or determinable payments that are not quoted in an active market. Such assets are recognised initially at fair value plus any directly attributable transaction costs.
Subsequent to initial recognition, loans and receivables are measured at amortised cost using the effective interest method, less any impairment losses.
Loans and receivables comprise trade and other receivables, cash and cash equivalents and loans to subsidiaries (for Company purposes only).
Cash and cash equivalents comprise cash balances and call deposits with maturities of three months or less from the acquisition date that are subject to an insignificant risk of changes in their fair value, and are used by the Group in the management of its short-term commitments.
Non-derivative financial liabilities - measurement
Other financial liabilities are recognised initially at fair value less any directly attributable transaction costs. Subsequent to initial recognition, these financial liabilities are measured at amortised cost using the effective interest method.
Other financial liabilities comprise shareholders’ loans, trade and other payables, shareholders for dividends and loans from subsidiaries (for Company purposes only).
Inventories
Inventories are measured at the lower of cost or net realisable value.
Cost includes expenditure incurred in acquiring, manufacturing and transporting the inventory to its present location. Manufacturing costs include an allocated portion of production overheads which are directly attributable to the cost of manufacturing such inventory. The allocation is determined based on the normal production capacity.
Cost is determined as follows -
Raw materials weighted average
Finished product and trading goods standard cost
Net realisable value is the estimated selling price in the ordinary course of business, less the cost of completion and selling expenses. Aged and discontinued finished goods, slow moving consumable stores and obsolete raw materials are identified on a regular basis and are written down to their estimated net realisable value.
Impairment
Impairment of non-financial assets
24

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
The Group’s non-financial assets, other than inventories and deferred taxation assets, are reviewed at each reporting date or whenever events or changes in circumstances indicate that the carrying amount may not be recoverable, to determine whether there is any indication of impairment.
Impairment (continued)
Impairment of non-financial assets (continued)
For impairment testing, assets are grouped together into the smallest group of assets that generates cash inflows from continuing use that are largely independent of the cash inflows of other assets or cash generating units (“CGUs”). Goodwill arising from a business combination is allocated to CGUs or groups of CGUs that are expected to benefit from the synergies of the combination.
The recoverable amount of an asset or CGU is the greater of its fair value less cost to sell and value in use. Value in use is based on the estimated future cash flows, discounted to their present value using a pre-taxation discount rate that reflects current market assessments of the time value of money and the risks specific to the asset or CGU.
The impairment loss recognised in profit or loss is the excess of the carrying amount over the recoverable amount.
Impairment losses recognised in respect of a cash-generating unit is first allocated to reduce the carrying amount of the goodwill allocated to the unit and then to reduce the carrying amounts of the other assets in the unit on a pro rata basis relative to their carrying amounts.
With the exception of goodwill, a previously recognised impairment loss will be reversed insofar as estimates change as a result of an event occurring after the impairment loss was recognised. An impairment loss is reversed only to the extent that the asset’s carrying amount does not exceed the carrying amount that would have been determined had no impairment loss been recognised.
A reversal of an impairment loss is recognised in profit or loss.
Impairment of financial assets
A financial asset is assessed at each reporting date to determine whether there is any objective evidence that it is impaired. A financial asset is considered to be impaired if objective evidence indicates that one or more loss events have occurred and have had a negative effect on the estimated future cash flows of that asset.
Objective evidence that financial assets are impaired can include default or delinquency by a debtor, restructuring of an amount due to the Group on terms that the Group would not consider otherwise or indications that a debtor or issuer will enter bankruptcy.
The Group considers evidence of impairment for receivables at both a specific asset and collective level. All individually significant receivables are assessed for specific impairment. All individually significant receivables found not to be specifically impaired are then collectively assessed for any impairment that has been incurred but not yet identified. Receivables that are not individually significant are collectively assessed for impairment by grouping together receivables with similar risk characteristics.
In assessing collective impairment the Group uses historical trends of the probability of default, timing of recoveries and the amount of loss incurred, adjusted for management’s judgement as to whether current economic and credit conditions are such that the actual losses are likely to be greater or less than suggested by historical trends.
An impairment loss in respect of a financial asset measured at amortised cost is calculated as the difference between its carrying amount and the present value of the estimated future cash flows discounted at the asset’s original effective interest rate. Impairment losses are recognised in profit or loss and reflected
25

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
in an allowance account against receivables. When a subsequent event causes the amount of impairment loss to decrease, the decrease in impairment loss is reversed through profit or loss.
Share capital
Ordinary shares
Ordinary shares are classified as equity. Incremental costs directly attributable to the issues of ordinary shares are recognised as a deduction from equity, net of any taxation effects.
Share capital (continued)
Repurchase and reissue of share capital (treasury shares)
When share capital recognised as equity is repurchased, the amount of the consideration paid, which includes directly attributable costs, net of any taxation effects, is recognised as a deduction from equity. Repurchased shares are classified as treasury shares and are presented in the reserve for own shares. When treasury shares are sold or reissued subsequently, the amount received is recognised as an increase in equity.
Employee benefits
Short-term employee benefits
Short-term employee benefit obligations are measured on an undiscounted basis and are expensed as the related service is provided. A liability is recognised for the amount expected to be paid under short-term cash bonus or profit-sharing plans if the Group has a present legal or constructive obligation to pay this amount as a result of past service provided by the employee, and the obligation can be estimated reliably.
Defined contribution plans
A defined contribution plan is a post-employment benefit plan under which the Group pays fixed contributions into a separate entity and has no legal or constructive obligation to pay further amounts. Obligations for contributions to defined contribution plans are recognised as an employee benefit expense in profit or loss in the period during which related services are rendered by employees. Prepaid contributions are recognised as an asset to the extent that a cash refund or a reduction in future payments is available. Contributions to a defined contribution plan that are due more than 12 months after year end of the period in which the employees render the service are discounted to their present value.
Equity settled share-based payments
The grant date fair value of share-based payment awards granted to employees is recognised as an employee expense, with a corresponding increase in equity (in the share-based payment reserve), over the vesting period of the awards. The amount recognised as an expense is adjusted to reflect the number of awards for which the related service and non-market vesting conditions are expected to be met, such that the amount ultimately recognised as an expense is based on the number of awards that do meet the related service and non-market performance conditions at the vesting date. For share-based payment awards with non-vesting conditions, the grant date fair value of the share-based payment is measured to reflect such conditions and there is no true-up for differences between expected and actual outcomes.
Cash settled share-based payments
The fair value of the amount payable to employees in respect of share appreciation rights, which are settled in cash, is recognised as an expense with a corresponding increase in liabilities, over the period that the employees unconditionally become entitled to payment. The liability is re-measured at each reporting date and at settlement date based on the fair value of the share appreciation rights. Any changes in the fair value of the liability are recognised as an employee benefit expense in profit or loss.
Dividends payable
26

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
Dividends payable and any dividends withholding taxation pertaining thereto are recognised in the year in which the dividends are declared.
Provision for rehabilitation
Provisions for rehabilitation costs are based on the estimated expense to be incurred in order to return clay quarries to a useable state. These costs include estimates made by management in order to comply with legislated environmental requirements. The adequacy of the provisions is reviewed annually against changed circumstances and legislation and any adjustment is recognised in profit or loss.
IFRS and IFRIC interpretations not yet effective
A number of new standards, amendments to standards and interpretations are not yet effective for the year ended 30 June 2018 and have not been applied in the preparation of these financial statements. At the date of authorisation of the financial statements of Avikro Industries Proprietary Limited and its subsidiaries for the year ended 30 June 2018, the following Standards and Interpretations were in issue but not yet effective -
IFRS 15 Revenue from contracts with customers
This standard replaces IAS 11 Construction Contracts, IAS 18 Revenue, IFRIC 13 Customer Loyalty Programmes, and IFRIC 15 Agreements for the Construction of Real Estate, IFRIC 18 Transfer of Assets from Customers and SIC-31 Revenue - Barter of Transactions Involving Advertising Services.
The standard contains a single model that applies to contracts with customers and two approaches to recognising revenue: at a point in time or over time. The model features a contract-based five-step analysis of transactions to determine whether, how much and when revenue is recognised.
The Group has assessed that the impact of this new standard would not have significant impact. All current revenue contracts have been considered, and the recognition and measurement impact of applying the amendments would be the same as the current revenue recognition and measurement.
The standard is effective for annual periods beginning on or after 1 July 2018, with early adoption permitted.
IFRS 9 Financial Instruments
On 24 July 2014 the IASB issued the final IFRS 9 Financial Instruments Standard, which replaces earlier versions of IFRS 9 and completes the IASB’s project to replace IAS 39 Financial Instruments: Recognition and Measurement.
The Group has assessed that the impact of the application of this standard will not have a significant impact on the Group.
In addition, the IFRS 9 impairment model has been changed from an “incurred loss” model from IAS 39 to an “expected credit loss” model, which may increase the provision for bad debts recognised in the Group.
The standard is effective for annual periods beginning on or after 1 July 2018 with retrospective application, early adoption is permitted.
Clarifying share-based payment accounting (Amendments to IFRS 2)
Currently, there is ambiguity over how a company should account for certain types of share-based payment arrangements. The IASB has responded by publishing amendments to IFRS 2 Share-based Payment.
The amendments cover three accounting areas:
27

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
Measurement of cash-settled share-based payments - There is currently no guidance in IFRS 2 on how to measure the fair value of the liability in a cash-settled share based payment. The amendments clarify that a cash-settled share-based payment is measured using the same approach as for equity-settled share-based payments - i.e. the modified grant date method. Therefore, in measuring the liability market and non-vesting conditions are taken into account in measuring its fair value and the number of awards to receive cash is adjusted to reflect the best estimate of those expected to vest as a result of satisfying service and any non-market performance conditions.
The new requirements do not change the cumulative amount of expense that is ultimately recognised, because the total consideration for a cash-settled share-based payment is still equal to the cash paid on settlement.
Classification of share-based payments settled net of taxation withholdings - The Group may be obligated to collect or withhold taxation related to a share-based payment, even though the taxation obligation is often a liability of the employee and not the Group. Currently, it is unclear whether the portion of the share-based payment that is withheld in these instances should be accounted for as equity-settled or cash-settled.
IFRS and IFRIC interpretations not yet effective (continued)
Clarifying share-based payment accounting (Amendments to IFRS 2) (continued)
The amendments introduce an exception stating that, for classification purposes, a share-based payment transaction with employees is accounted for as equity-settled if certain criteria are met.
Accounting for a modification of a share-based payment from cash-settled to equity-settled - There is no specific guidance in IFRS 2 that addresses the accounting when a share-based payment is modified from cash-settled to equity-settled. The amendments clarify the approach that companies are to apply.
The new requirements could affect the classification and/or measurement of these arrangements and potentially the timing and amount of expense recognised for new and outstanding awards. The amendments are effective for annual periods commencing on or after 1 July 2018.
IFRIC 22 Foreign Currency Transactions and Advance Considerations
When foreign currency consideration is paid or received in advance of the item it relates to - which may be an asset, an expense or income - IAS 21 The Effects of Changes in Foreign Exchange Rates is not clear on how to determine the transaction date for translating the related item.
This has resulted in diversity in practice regarding the exchange rate used to translate the related item. IFRIC 22 clarifies that the transaction date is the date on which the Group initially recognises the prepayment or deferred income arising from the advance consideration. For transactions involving multiple payments or receipts, each payment or receipt gives rise to a separate transaction date.
The interpretation may have an impact on the Company which could include a change in the determination of the transaction date of advance considerations.
The interpretation is effective for annual reporting periods beginning on or after 1 July 2018.
IFRS 16 Leases
IFRS 16 was published in January 2016. It sets out the principles for the recognition, measurement, presentation and disclosure of leases for both parties to a contract, i.e. the customer (‘lessee’) and the supplier (‘lessor’). IFRS 16 replaces the previous leases Standard, IAS 17 Leases, and related Interpretations. IFRS 16 has one model for lessees which will result in almost all leases being included on the Statement of Financial Position. No significant changes have been included for lessors.
The standard is effective for annual periods beginning on or after 1 July 2019, with early adoption permitted only if the entity also adopts IFRS 15. The transitional requirements are different for lessees and lessors. The Group has assessed that the impact of the application of this standard will not have a significant impact on the Group.
28

Avikro Industries Proprietary Limited
Accounting policies
for the year ended 30 June 2019 (continued)
All standards and Interpretations will be adopted at their effective dates.
29

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018

|  | Group |  | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
1. | Revenue | R000’s |  | R000’s |  | R000’s |  | R000’s
| Sale of goods | 3 343 674 |  |  | 3 039 422 |  |  | — |  |  | — |
| Investment income | — |  |  | — |  |  | 585 |  |  | 280 493 |
|  | 3 343 674 |  |  | 3 039 422 |  |  | 585 |  |  | 280 493 |

|  | Group
|  | 2019 |  | 2018
2. | Operating profit | R000’s |  | R000’s
| The following items have been charged/(credited) in arriving at operating profit - |  |  |
| Auditors’ remuneration | 3 140 |  |  | 2 969 |
| - Fees for audit | 2 185 |  |  | 1 842 |
| - Prior year under-provision | 884 |  |  | 783 |
| - Fees for other services | 71 |  |  | 344 |
| Depreciation | 167 935 |  |  | 147 755 |
| - Buildings | 36 370 |  |  | 33 022 |
| - Plant and machinery, motor vehicles and office equipment | 131 565 |  |  | 114 733 |
| Fees paid for | 23 856 |  |  | 28 376 |
| - Managerial services | 14 145 |  |  | 11 423 |
| - Secretarial services | 195 |  |  | 215 |
| - Technical services | 9 516 |  |  | 16 738 |
| Inventory (write-up)/written-down | (2 036) |  |  | 460 |
| Raising of impairment on trade receivables | 276 |  |  | 1 499 |
| Loss/(profit) on disposal of property, plant and equipment | 131 |  |  | (451) |
| Operating lease charges in respect of equipment | 18 283 |  |  | 17 213 |
| Retirement fund contributions | 22 865 |  |  | 21 590 |
| Salaries and wages | 386 977 |  |  | 370 500 |
| Share-based payment expense | 29 814 |  |  | 43 954 |
| - Cash-settled | 1 207 |  |  | 1 832 |
| - Equity-settled - Avikro Industries Proprietary Limited | 26 460 |  |  | 38 957 |
| - Equity-settled - National Avikro Australia Proprietary Limited | 2 147 |  |  | 3 165 |

2. | Operating profit (continued)

30

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
Long Term Incentive Plan ("LTIP")
In June 2016 the Avikro Remcom made a number of new awards in terms of the company’s LTIP scheme which was approved at the annual general meeting of shareholders held on 30 November 2007.
The following table reflects the number of notional Avikro shares granted and held by the participants-

|  | Number of awards
|  | 2019 | 2018
| At beginning of year | 25 000 |  |  | 25 000 |
| Options awarded | 5 000 |  |  | — |
| Options forfeited | (5 000) |  |  |
| At end of year | 25 000 |  |  | 25 000 |

The liability raised for the awards outstanding at 30 June 2019 was R2.5 million (2018 - R1.3 million). Included as an expense in profit or loss for the year was R1.2 million (2018 - R1.2 million) relating to the current year amortisation of the share options granted.
The LTIP award is similar to a forward on Avikro ordinary shares maturing at tranche measuring date where the strike price is R Nil. A no-arbitrage approach is therefore used to determine the fair value of the awards.
The liability will be measured at the end of each reporting period, until settled in cash, by applying an option pricing model, taking into account the terms and conditions on which the awards were granted and to the extent to which the employees have rendered services to the company.
25% of the awards will vest on 1 June 2019 and 75% will vest on 1 June 2021.
The Avikro Industries Proprietary Limited Equity Incentive Scheme
Following the termination of the Avikro Industries Proprietary Limited Share Incentive Trust and in accordance with the terms of the offer made by Italtile to Avikro shareholders in October 2012, the Board has implemented a new share incentive scheme.
The new scheme, known as the Avikro Industries Proprietary Limited Equity Incentive Scheme (“EIS”) was implemented with effect from 1 July 2013.The purpose of the scheme is to incentivise selected employees by giving them the opportunity to acquire shares in Avikro. The scheme will also ensure that the goals of those employees will be aligned with the goals of the other shareholders.
In terms of the rules of the EIS, grants will be made at the discretion of the Avikro Remuneration Committee ("Remcom") on 1 July each year. Per the scheme rules 20% of the grants will be unconditional but the remaining 80% will be conditional on the achievement of performance targets set by the Remcom. There will be two vesting dates which will be on the second and fourth anniversary dates of the original grant date. Per the scheme rules 25% of the grants will vest on the first vesting date and 75% will vest on the second vesting date.

2. | Operating profit (continued)

31

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
The Avikro Industries Proprietary Limited Equity Incentive Scheme
Details of the grants issued and outstanding at 30 June 2019 are as follows -

| Grant date | Vesting date | Category | Grants outstanding
| 1 July 2014 | 30 June 2018 | Unconditional | 7 500
| 1 July 2014 | 30 June 2018 | Conditional | 30 000
| 1 July 2015 | 30 June 2019 | Unconditional | 15 000
| 1 July 2015 | 30 June 2019 | Conditional | 60 000
| 1 July 2017 | 30 June 2019 | Unconditional | 4 000
| 1 July 2017 | 30 June 2019 | Conditional | 14 500 |
| 30 May 2018 | 30 June 2019 | Unconditional | 750 |
| 30 May 2018 | 30 June 2019 | Conditional | 2 250
| 1 July 2017 | 30 June 2021 | Unconditional | 13 500 |
| 1 July 2017 | 30 June 2021 | Conditional | 48 000 |
| 30 May 2018 | 30 June 2021 | Unconditional | 3 000
| 30 May 2018 | 30 June 2021 | Conditional | 9 000
| Total |  |  | 207 500 |

Included as an expense in profit or loss for the year was R9.8 million (2018 - R21.7 million relating to the current year amortisation of the share options granted.
During the year 662 500 shares vested at a weighted average share price of R241.46 per share.
Below follow details of shares which vested from the 1 July 2013 issue -

Participant | Shares
LA Foxcroft | 262 500 |
DR Alston | 150 000 |
T Molefakgotla | 150 000 |
L Peters | 37 500 |
C Masombuka | 37 500 |
Total | 637 500 |

Below follow details of shares which vested from the 1 July 2015 issue -

Participant | Shares
J Snyman | 12 500 |
E Domoney | 12 500 |
Total | 25 000 |

Due to early termination, K Gibb forfeited his 37 500 shares from the 1 July 2014issue and L Peters forfeited 50 000 shares from the 1 July 2017 issue.

2. | Operating profit (continued)

32

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
Executive Share Scheme
On 24 March 2016 shareholders approved the issue of 414 139 ordinary shares to the three executive directors of the company, the chief executive officer (207 069 shares), the chief operating officer (165 656 shares) and the chief financial officer (41 414 shares).
The shares are being held in trust by an escrow agent and will vest to the participants provided they remain in the full time employment of the company for the period 1 January 2016 to 31 December 2020. If the participants' full time employment with the company terminates prior to 31 December 2020, the participant shall forfeit all the shares issued to him irrespective of the date on which termination occurs.
The chief financial officer reitired 30 November 2017 and forfeited all of his 41 414 shares.
A new issue of 30 000 shares was approved on 1 January 2018 and the same rules apply as above.
The Executive Share award is similar to simply holding Avikro ordinary shares from grant date.
Since the Executive Shares are an equity-settled award the cost is fixed at grant based on the fair value of Avikro ordinary shares at that date and expensed over the vesting period. At each reporting period the Group will adjust the cost for the service period by taking into account resignations, deaths and retirements during the vesting period.
Mr R Mothapo (Fellow of the Actuarial Society of South Africa) of the Matlotlo Group Proprietary Limited has valued the above issue of shares at R54.4 million. This cost will be amortised over the vesting period.
Included as an expense in profit or loss for the year was R16.6 million (2018 - R17.2 million) relating to the current year amortisation of the shares issued.
33

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

|  | Group |  | Company
|  | 2018 |  | 2017 |  | 2018 |  | 2017
3. | Finance income | R000’s |  | R000’s |  | R000’s |  | R000’s
| Interest received from banks | 12 109 |  |  | 11 761 |  |  | — |  |  | — |
| Interest received from the South African Revenue Services | 753 |  |  | 397 |  |  | — |  |  | 1 |
| Dividends received | 733 |  |  | 4 562 |  |  | — |  |  | — |
| Net foreign exchange gains | 12 383 |  |  | 9 493 |  |  | 3 043 |  |  | — |
|  | 25 978 |  |  | 26 212 |  |  | 3 043 |  |  | 1 |

|  | Group |  | Company
|  | 2018 |  | 2017 |  | 2018 |  | 2017
4. | Finance expense | R000’s |  | R000’s |  | R000’s |  | R000’s
| Interest paid to South African Revenue Services | 77 |  |  | 16 |  |  | 8 |  |  | 16 |
| Other interest paid | 8 |  |  | — |  |  | — |  |  | — |
| Net foreign exchange losses | — |  |  | — |  |  | — |  |  | 20 459 |
|  | 85 |  |  | 16 |  |  | 8 |  |  | 20 475 |

|  | Group |  |  | Company |
|  | 2018 |  | 2017 |  |  | 2018 |  | 2017 |
5. | Taxation | R000's |  | R000's |  |  | R000's |  | R000's |
| Normal taxation |  |  |  |  |  |  |  |  |
| Current taxation | 107 923 |  |  | 127 703 |  |  |  | 3 239 |  |  | 1 504 |  |
| - current year | 128 124 |  |  | 137 753 |  |  |  | 3 310 |  |  | 1 304 |  |
| - prior year (over)/under-provision | (20 201) |  |  | (10 050) |  |  |  | (71) |  |  | 200 |  |
| Deferred taxation | 19 103 |  |  | 24 355 |  |  |  | (2 439) |  |  | (7 142) |  |
| - current year | 18 750 |  |  | 24 365 |  |  |  | (2 439) |  |  | (7 142) |  |
| - prior year under/(over)-provision | 353 |  |  | (10) |  |  |  | — |  |  | — |  |
| Total normal taxation | 127 026 |  |  | 152 058 |  |  |  | 800 |  |  | (5 638) |  |
| Dividends withholding taxation | — |  |  | 221 |  |  | — |  | — |  |  | 221 |  |
| Total taxation charge | 127 026 |  |  | 152 279 |  |  |  | 800 |  |  | (5 417) |  |

34

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

5. | Taxation (continued)

South Africa standard rate of taxation is 28%.
Australia standard rate of taxation is 30%.
The effective rate of taxation differs from the standard rate of taxation as follows -

| Group |  | Company
| 2018 |  | 2017 |  | 2018 |  | 2017
| % |  | % |  | % |  | %
Standard rate of taxation | 28.00 |  |  | 28.00 |  |  | 28.00 |  |  | 28.00 |
Dividends received | (0.24) |  |  | (0.45) |  |  | — |  |  | (30.28) |
Realisation of deductible expense (treasury shares) | (3.82) |  |  | — |  |  | — |  |  | — |
Equity settled share-based payment expense | 0.21 |  |  | 1.72 |  |  | — |  |  | — |
Other disallowed expenditure | 0.37 |  |  | 0.12 |  |  | 6.35 |  |  | 0.02 |
Shares re-purchased from share participants | — |  |  | (0.13) |  |  | — |  |  | — |
Normal taxation prior year adjustment | (3.37) |  |  | 0.04 |  |  | (2.78) |  |  | 0.09 |
Deferred taxation prior year adjustment | 0.06 |  |  | (1.81) |  |  | — |  |  | 0.08 |
Total taxation charge | 21.21 |  |  | 27.49 |  |  | 31.57 |  |  | (2.09) |

35

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

6. | Property, plant and equipment |  |  |  |  |
|  | Cost |  | Accumulated depreciation |  | Carrying amount
| 2018 | R000’s |  | R000’s |  | R000’s
| Group |  |  |  |  |
| Land and buildings | 779 500 |  |  | (286 905) |  |  | 492 595 |
| Plant and machinery, vehicles and office equipment | 2 375 681 |  |  | (1 548 538) |  |  | 827 143 |
| Capital work-in-progress | 230 060 |  |  | — |  |  | 230 060 |
|  | 3 385 241 |  |  | (1 835 443) |  |  | 1 549 798 |
| Company |  |  |  |  |
| Land and buildings | 4 263 |  |  | — |  |  | 4 263 |
| 2017 |  |  |  |  |
| Group |  |  |  |  |
| Land and buildings | 718 974 |  |  | (233 014) |  |  | 485 960 |
| Plant and machinery, vehicles and office equipment | 1 975 655 |  |  | (1 313 798) |  |  | 661 857 |
| Capital work in progress | 245 069 |  |  | — |  |  | 245 069 |
|  | 2 939 698 |  |  | (1 546 812) |  |  | 1 392 886 |
| Company |  |  |  |  |
| Land and buildings | 4 263 |  |  | — |  |  | 4 263 |

36

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

6. | Property, plant and equipment (continued)
|  | Land and buildings |  | Plant and machinery, vehicles and office equipment |  | Capital work-in-progress |  | Total
| 2018 | R000’s |  | R000’s |  | R000’s |  | R000’s
| Group |  |  |  |  |  |  |
| Carrying amount at beginning of year | 485 960 |  |  | 661 857 |  |  | 245 069 |  |  | 1 392 886 |
| Additions net of transfers from capital work-in-progress | 42 125 |  |  | 287 556 |  |  | (15 180) |  |  | 314 501 |
| Carrying amount of disposals | — |  |  | (3 083) |  |  | — |  |  | (3 083) |
| Depreciation charge | (36 370) |  |  | (131 565) |  |  | — |  |  | (167 935) |
| Translation differences | 880 |  |  | 12 378 |  |  | 171 |  |  | 13 429 |
| Carrying amount at end of year | 492 595 |  |  | 827 143 |  |  | 230 060 |  |  | 1 549 798 |
| Company |  |  |  |  |  |  |
| Carrying amount at beginning and end of year | 4 263 |  |  |  |  |  |  | 4 263 |
| 2017 |  |  |  |  |  |  |
| Group |  |  |  |  |  |  |
| Carrying amount at beginning of year | 341 053 |  |  | 585 948 |  |  | 258 546 |  |  | 1 185 547 |
| Additions net of transfers from capital work-in-progress | 187 296 |  |  | 199 058 |  |  | (12 672) |  |  | 373 682 |
| Carrying amount of disposals | — |  |  | (2 224) |  |  | — |  |  | (2 224) |
| Depreciation charge | (33 022) |  |  | (114 733) |  |  | — |  |  | (147 755) |
| Translation differences | (9 367) |  |  | (6 192) |  |  | (805) |  |  | (16 364) |
| Carrying amount at end of year | 485 960 |  |  | 661 857 |  |  | 245 069 |  |  | 1 392 886 |
| Company |  |  |  |  |  |  |
| Carrying amount at beginning of year | 4 263 |  |  |  |  |  |  | 4 263 |

A register of land and buildings is available for inspection at the registered office detailing cost and improvements. Refer to note 20 for details of future contractual commitments to acquire property, plant and equipment.
37

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

|  | Group
|  | 2018 |  | 2017
7. | Goodwill | R000's |  | R000's
| Opening and closing balances | 4 520 |  |  | 4 520 |

The goodwill arose in previous years on the acquisition of an additional 5% interest in National Avikro Industries Australia Proprietary Limited and the investment in Sphinx Acrylic Bathroomware Proprietary Limited.
The recoverable amounts of the cash-generating units, as assessed by management, were based on their value in use. The results of these tests did not identify any impairment charge.

|  |  | Group |
|  |  | 2018 |  |  | 2017 |
8. | Equity-accounted investee |  | R000’s |  |  | R000’s |
| Unlisted ordinary shares |  |  |  |  |  |
| Investment at cost |  | 19 559 |  |  |  | 19 559 |  |
| Additional investment acquired |  | 1 781 |  |  |  | — |  |
| Share of profit of equity-accounted investees, net of taxation since acquisition |  | 49 229 |  |  |  | 38 398 |  |
| Share of opening accumulated profits |  | 38 398 |  |  |  | 29 267 |  |
| Dividends received |  | (4 402) |  |  |  | (4 309) |  |
| Share of profit for the year, net of taxation |  | 15 233 |  |  |  | 13 440 |  |
| Carrying amount at end of year |  | 70 569 |  |  |  | 57 957 |  |

38

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
8 Equity accounted investee (continued)
The information below illustrates summarised financial information of the Group’s investment in Ezee Tile group of companies (“Ezee Tile”) at 100%.

| Group
| 2018 |  | 2017
| R000’s |  | R000’s
Statement of profit or loss and other comprehensive income |  |  |
Revenue | 613 369 |  |  | 523 430 |
Profit before taxation | 58 610 |  |  | 52 844 |
Income tax expense | (16 440) |  |  | 14 758 |
Net profit after taxation | 42 170 |  |  | 67 602 |
Group’s share of profit | 15 233 |  |  | 13 440 |
Statement of financial position |  |  |
Non-current assets | 71 777 |  |  | 44 545 |
Current assets | 164 817 |  |  | 143 861 |
Total assets | 236 594 |  |  | 188 406 |
Capital and reserves | 179 729 |  |  | 133 803 |
Non-current liabilities | 1 066 |  |  | 1 247 |
Current liabilities | 55 799 |  |  | 53 356 |
Total equity and liabilities | 236 594 |  |  | 188 406 |

Ezee Tile is a manufacturer of adhesives, grout and related products. Ezee Tile has six manufacturing plants located throughout South Africa. The plants are split into two separate legal entities and the Group’s interest in each entity varies between 17.85% and 36.60%. The Group has determined that it has significant influence because it has 25% representation on the board of the investee.
The Group’s share of profits has been determined by reference to the audited annual financial information for the year ended 30 June 2018.
39

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2017 (continued)
9. Investment in subsidiaries

|  |  |  | Percentage holding |  | Cost of shares |  | Loans to/(from) subsidiaries
Held by Avikro Industries Proprietary Limited |  | Issued share capital |  | 2019 |  | 2018 |  | 2019 |  | 2018 |  | 2019 |  | 2018
|  |  |  | % |  | % |  | R000's |  | R000's |  | R000's |  | R000's
Operating companies |  |  |  |  |  |  |  |  |  |  |  |  |  |
Aquarella Investments 389 Proprietary Limited | (R) | 100 |  |  | 74 |  |  | 74 |  |  | * |  | * |  | — |  |  | — |
National Avikro Industries South Africa Proprietary Limited | (R) | 2 000 |  |  | 100 |  |  | 100 |  |  | 149 703 |  |  | 125 512 |  |  | (543 542) |  |  | (358 681) |
Sphinx Acrylic Bathroomware Proprietary Limited | (R) | 102 |  |  | 100 |  |  | 100 |  |  | 290 237 |  |  | 287 803 |  |  | (24 369) |  |  | (24 370) |
Holding companies and indirect subsidiaries |  |  |  |  |  |  |  |  |  |  |  |  |  |
National Avikro Industries Proprietary Limited | (R) | 100 000 |  |  | 100 |  |  | 100 |  |  | 11 272 |  |  | 11 272 |  |  | 8 398 |  |  | 8 398 |
National Avikro Industries Australia Proprietary Limited | (AUD) |  |  |  |  |  |  |  |  |  |  | 163 496 |  |  | 181 754 |
Avikro Holdings Proprietary Limited | (AUD) | 1 |  |  | 99000 |  | 99000 |  | 71 045 |  |  | 71 045 |  |  | — |  |  | — |
|  |  |  |  |  |  |  | 522 257 |  |  | 495 632 |  |  | (396 017) |  |  | (192 899) |
* Less than R1 000 |  |  |  |  |  |  |  |  |  |  |  |  |  |
|  |  |  |  |  |  |  |  |  |  |  | Company
|  |  |  |  |  |  |  |  |  |  |  | 2019 |  | 2018
|  |  |  |  |  |  |  |  |  |  |  | R000’s |  | R000’s
Shares at cost |  |  |  |  |  |  |  |  |  |  |  | 522 257 |  |  | 495 632 |
Loans to subsidiaries |  |  |  |  |  |  |  |  |  |  |  | 171 894 |  |  | 190 152 |
Investment in subsidiaries |  |  |  |  |  |  |  |  |  |  |  | 694 151 |  |  | 685 784 |
Loans from subsidiaries |  |  |  |  |  |  |  |  |  |  |  | (567 911) |  |  | (383 051) |

The loans to subsidiaries are unsecured, have no fixed terms of repayment and do not bear interest. The company will, however, not call for settlement of these loans within the next twelve months.
The loans from subsidiaries are unsecured, do not bear interest and have no fixed terms of repayment.
40

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2017 (continued)
9. Investment in subsidiaries (continued)

|  |  |  | Percentage holding |  | Cost of shares
|  | Issued share capital |  | 2019 |  | 2018 |  | 2019 |  | 2018
|  |  |  | % |  | % |  | R000's |  | R000's
Held by National Avikro Industries South Africa Proprietary Limited |  |  |  |  |  |  |  |  |  |
Dormant company |  |  |  |  |  |  |  |  |  |
Mollyn 55 Proprietary Limited | (R) | 100 |  |  | 100 |  |  | 100 |  |  | — |  |  | — |
Held by National Avikro Industries Proprietary Limited |  |  |  |  |  |  |  |  |  |
Dormant company |  |  |  |  |  |  |  |  |  |
CRM Brick and Associated Industries Proprietary Limited | (R) | 2 000 |  |  | 100 |  |  | 100 |  |  | 2 |  |  | 2 |
Held by Aquarella Investments 389 Proprietary Limited |  |  |  |  |  |  |  |  |  |
East Cape Quarries Proprietary Limited | (R) | 10 000 |  |  | 100 |  |  | 100 |  |  | 10 |  |  | 10 |
Mayfield Clays Proprietary Limited | (R) | 100 |  |  | 100 |  |  | 100 |  |  | * |  | *
Held by Avikro Holdings Proprietary Limited |  |  |  |  |  |  |  |  |  |
National Avikro Industries Australia Proprietary Limited | (AUD) | 200 |  |  | 96.9 |  |  | 96.9 |  |  | 71 045 |  |  | 71 045 |

All holdings are in the ordinary share capital of the undertaking concerned.
* Less than R1 000
41

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

|  | Group
|  | 2019 |  | 2018
10. | Inventories | R000’s |  | R000’s
| Raw materials | 129 045 |  |  | 90 999 |
| Finished goods and merchandise | 150 928 |  |  | 143 372 |
|  | 279 973 |  |  | 234 371 |

The write-(up)/down of inventories recognised as an (income)/expense was (R2.0 million) (2018 - R0.5 million). This (income)/expense is included in cost of sales.

|  | Group |  | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
11. | Trade and other receivables | R000’s |  | R000’s |  | R000’s |  | R000’s
| Financial assets | 586 166 |  |  | 476 088 |  |  | 6 261 |  |  | 6 034 |
| Trade receivables | 509 340 |  |  | 433 149 |  |  | — |  |  | — |
| Sundry debtors | 76 826 |  |  | 42 939 |  |  | 6 261 |  |  | 6 034 |
| Non-financial assets | 48 268 |  |  | 28 414 |  |  | — |  |  | — |
| Prepayments | 19 650 |  |  | 25 459 |  |  | — |  |  | — |
| Other | 9 856 |  |  | 1 462 |  |  | — |  |  | — |
| VAT | 18 762 |  |  | 1 493 |  |  | — |  |  | — |
|  | 634 434 |  |  | 504 502 |  |  | 6 261 |  |  | 6 034 |
|  |  | Group
|  |  | 2019 |  | 2018
|  |  | R000’s |  | R000’s
| Trade receivables comprise of - |  |  |  |
| Gross receivables - external |  | 487 260 |  |  | 352 867 |
| - related parties (refer to note 22) |  | 71 396 |  |  | 128 192 |
|  |  | 558 656 |  |  | 481 059 |
| Impairment allowance against trade receivables |  | (5 142) |  |  | (5 142) |
| Other allowances against trade receivables |  | (44 174) |  |  | (42 768) |
|  |  | 509 340 |  |  | 433 149 |

42

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

11. | Trade and other receivables (continued)

The write down of trade receivables recognised as an expense was R0.3 million (2018 - R1.5 million).
Movement in the impairment allowance against trade receivables was as follows -

| Group
| 2019 |  | 2018
| R000’s |  | R000’s
Balance at beginning of year | 5 142 |  |  | 5 142 |
Charge for the year | 276 |  |  | 1 499 |
Utilised | (276) |  |  | (1 499) |
Balance at end of year | 5 142 |  |  | 5 142 |
Other allowances against trade receivables are comprised of - |  |  |
Allowance for rebates | 43 587 |  |  | 37 598 |
Allowance for settlement discounts | 587 |  |  | 5 170 |
| 44 174 |  |  | 42 768 |

The Group generally deals with large corporates who have a sound credit rating. Management views the risk profile of customers per industry as well spread and managed as discussed below.
Collateral is generally not held for blue chip companies due to their sound payment history. Collateral is obtained on certain smaller entities and certain foreign customers, where appropriate, as security for outstanding amounts.
Trade receivables comprise a widespread customer base. This is made up primarily of merchants and wholesalers trading in Avikro and porcelain tiles, vitreous china sanitaryware and acrylic bathroomware. The Group does not have any significant exposure to any one customer, other than Italtile Limited, through its own stores, which comprise 13% (2018 - 27%) of the gross trade receivables balance.
The Group sells principally to merchants and wholesalers in South Africa and most Southern African countries.
Foreign currency trade receivables included in note 19 relate to foreign supplier prepayments and creditors with debit balances that have been reclassified to trade and other receivables.
43

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

11. | Trade and other receivables (continued)

Credit risk is minimised through an initial new client acceptance procedure whereby potential customers are individually assessed before an appropriate credit limit is allocated to the new client. Ongoing credit evaluations of the financial position of customers is performed.
Management sets the trade receivables days per geographic region in accordance with the Group’s standard payment terms for that region. Trade receivable terms differ in the Africa and Australia regions due to local economic and market conditions and the risks involved in trading in those regions.
The following table illustrates the ageing of gross trade receivables. The impairment allowance against trade receivables of R5.1 million (2018 - R5.1 million) relates to the past due 61+ days ageing category only.

| Group
| 2019 |  | 2018
| R000’s |  | R000’s
Not past due | 436 940 |  |  | 391 259 |
Past due 0 - 30 days | 81 761 |  |  | 45 969 |
Past due 31 - 60 days | 10 919 |  |  | 23 416 |
Past due 61+ days | 29 036 |  |  | 20 415 |
| 558 656 |  |  | 481 059 |

Listings of overdue customer balances are reviewed monthly and evaluated against their credit terms and limits. Any customer exceeding their credit limits/terms are required to settle their overdue balances before any further credit is extended. Appropriate action is taken to recover outstanding amounts, where necessary.
At 30 June 2019, management did not consider there to be any material concentration of credit risk which has not been adequately provided for. Management consider the risk of irrecoverability as low.

|  | Group |  | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
12. | Cash and cash equivalents | R000’s |  | R000’s |  | R000’s |  | R000’s
| Cash and bank balances | 210 572 |  |  | 130 166 |  |  | 517 |  |  | 282 |
| Short-term deposits and marketable securities | 3 147 |  |  | 121 696 |  |  | — |  |  | — |
|  | 213 719 |  |  | 251 862 |  |  | 517 |  |  | 282 |

Cash at banks earns interest at floating rates based on daily bank deposit rates. Short-term deposits are made for varying periods of between one day and 3 months, depending on the immediate cash requirements of the Group and earn interest at the respective short-term deposit rates.
The fair value approximates the carrying value due to the short-term nature of these balances.
44

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

|  | Group | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
13. | Share capital | R000’s |  | R000’s |  | R000’s |  | R000’s
| Authorised 27 709 467 ordinary shares of no par value |  |  |  |  |  |  |
| Issued 19 391 700 ordinary shares no par value | 64 816 |  |  | 64 816 |  |  | 64 816 |  |  | 64 816 |

The remaining unissued shares are under the control of the directors until the next annual general meeting.
As disclosed in Note 2, 414 139 ordinary shares were approved for issue to executive directors. These shares will only be "fully paid" when the vesting conditions of the Executive Share Scheme have been met.

|  | Group
|  | 2019 |  | 2018
|  | R000’s |  | R000’s
| Number of shares issued to external parties - |  |  |
| Total shares in issue | 19 391 700 |  |  | 18 988 975 |
| Treasury shares | (465 640) |  |  | (830 281) |
| Net shares held by external parties | 18 926 060 |  |  | 18 158 694 |

14. | Treasury shares

National Avikro Industries South Africa Proprietary Limited, a wholly owned subsidiary of Avikro Industries Proprietary Limited, holds 465 640 (2018 - 830 281) shares in Avikro Industries Proprietary Limited.
45

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
15. Shareholders’ loans
The shareholders’ loans are unsecured, have no fixed terms of repayment and do not bear interest. The loans are owed to the minority shareholders in National Avikro Industries Australia Proprietary Limited.

| Group
| 2019 |  | 2018
| R000’s |  | R000’s
Balance at end of year | 3 314 |  |  | 3 808 |

|  | Group |  |  | Company |
|  | 2019 |  |  | 2018 |  |  | 2019 |  |  | 2018 |
16. | Deferred taxation | R000’s |  |  | R000’s |  |  | R000’s |  |  | R000’s |
| The movement on the deferred taxation account is as follows - |  |  |  |  |  |  |  |  |  |  |
| Balance at beginning of year | 75 891 |  |  |  | 56 714 |  |  |  | 16 696 |  |  |  | 23 838 |  |
| Profit or loss | 19 103 |  |  |  | 24 355 |  |  |  | (2 439) |  |  |  | (7 142) |  |
| - Current year | 18 750 |  |  |  | 24 365 |  |  |  | (2 439) |  |  |  | (7 142) |  |
| - Prior year under/(over)-provision | 353 |  |  |  | (10) |  |  |  | — |  |  |  | — |  |
| Other comprehensive income |  |  |  |  |  |  |  |  |  |  |
| - current year | 852 |  |  |  | (7 142) |  |  |  | — |  |  |  | — |  |
| Translation differences | 1 |  |  |  | 1 964 |  |  |  |  |  |  |  |
| Balance at end of year | 95 847 |  |  |  | 75 891 |  |  |  | 14 257 |  |  |  | 16 696 |  |
| Balance at end of year comprises - |  |  |  |  |  |  |  |  |  |  |
| Deferred taxation assets | (2 102) |  |  |  | (1 629) |  |  |  | — |  |  |  | — |  |
| Deferred taxation liabilities | 97 949 |  |  |  | 77 520 |  |  |  | 14 257 |  |  |  | 16 696 |  |
| Net deferred taxation liabilities | 95 847 |  |  |  | 75 891 |  |  |  | 14 257 |  |  |  | 16 696 |  |
| Comprising - |  |  |  |  |  |  |  |  |  |  |
| Capital allowances | 115 690 |  |  |  | 95 449 |  |  |  | — |  |  |  | — |  |
| Provisions | (22 350) |  |  |  | (30 527) |  |  |  | — |  |  |  | — |  |
| Foreign currency translation reserve | 2 507 |  |  |  | 10 969 |  |  |  | — |  |  |  | — |  |
| Foreign currency translation |  |  |  |  |  |  | 14 257 |  |  |  | 16 696 |  |
|  | 95 847 |  |  |  | 75 891 |  |  |  | 14 257 |  |  |  | 16 696 |  |

46

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

|  | Group
|  | 2019 |  | 2018
17. | Trade and other payables | R000’s |  | R000’s
| Financial liabilities | 306 920 |  |  | 261 559 |
| Trade payables | 260 157 |  |  | 232 754 |
| Accruals | 46 763 |  |  | 28 805 |
| Non-financial liabilities | 74 263 |  |  | 60 673 |
| Liability for SARS and LTIP | 2 515 |  |  | 1 308 |
| Employee related liabilities | 64 368 |  |  | 52 738 |
| Other | 7 246 |  |  | 2 897 |
| VAT | 134 |  |  | 3 730 |
|  | 381 183 |  |  | 322 232 |

|  | Group
|  | 2019 |  | 2018
18. | Provision for rehabilitation | R000’s |  | R000’s
| Provision for rehabilitation of clay quarries |  |  |
| Carrying amount at beginning of year | 20 777 |  |  | 20 327 |
| Additional provision raised | 6 632 |  |  | 450 |
| Utilised during the year | (6 949) |  |  | — |
| Carrying amount at end of year | 20 460 |  |  | 20 777 |

A provision is recognised for the rehabilitation of the quarries based on an assessment from an independent consultant working in conjunction with management. Reports on the rehabilitation assessment are lodged with the Department of Minerals and Energy each year.
The provision represents the best estimate of the current costs of either restoring the quarries to their original state or eliminating adverse environmental impacts to an acceptable level over the long term.
19. Financial instruments
The Group’s principal financial liabilities comprise shareholders' loans, trade and other payables and shareholders for dividends. The Company's financial liabilities comprise loans from subsidiaries and shareholders for dividends. The main purpose of these financial liabilities is to raise finance for the Group’s operations. The Group has various financial assets, such as trade and other receivables and cash and cash equivalents, which arise directly from its operations. The Company's financial assets comprise loans to subsidiaries, trade and other receivables and cash and cash equivalents.
The main risk arising from the Group’s financial instruments are currency risk, credit risk, interest rate risk and liquidity risk. The Board of Directors reviews and agrees policies for managing each of these risks, which are summarised in the notes that follow.
47

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
19. Financial instruments (continued)
Currency risk
The Group incurs currency risk as a result of purchases, borrowings and cash held in foreign currencies.
The foreign currencies in which the Group primarily deals are Euros, US Dollars and British Pounds.
The Group has exposure to foreign currency relating to the following assets/(liabilities) which have not been covered by forward exchange contracts at 30 June 2019.

| Foreign currency |  | Currency |  | Rand equivalent
| FC000’s |  |  |  | R000’s
Trade and other payables |  |  |  |  | (22 638) |
| (1 190) |  |  | EUR |  | (19 002) |
| (4) |  |  | GBP |  | (69) |
| (260) |  |  | USD |  | (3 567) |
Trade and other receivables |  |  |  |  | 10 297 |
| 420 |  |  | EUR |  | 6 707 |
| 262 |  |  | USD |  | 3 590 |
Foreign currency held in local CFC bank accounts |  |  |  |  | 3 463 |
| 215 |  |  | EUR |  | 3 430 |
| 2 |  |  | GBP |  | 27 |
| * |  | USD |  | 6 |

* Less than FC1000
48

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
19. Financial instruments (continued)
Currency risk (continued)
The following foreign currency balances have been consolidated in the Group financial statements at 30 June 2019.

| Foreign currency |  | Currency |  | Rand equivalent
| FC000’s |  |  |  | R000’s
Assets |  |  |  |  |
Property, plant and equipment | 20 616 |  |  | AUD |  | 208 897 |
Inventories | 8 334 |  |  | AUD |  | 84 442 |
Trade and other receivables | 14 114 |  |  | AUD |  | 156 631 |
Cash and cash equivalents | 597 |  |  | AUD |  | 6 050 |
Liabilities |  |  |  |  |
Deferred taxation liability | (106) |  |  | AUD |  | (1 071) |
Shareholders’ loans | (327) |  |  | AUD |  | (3 314) |
Trade and other payables | (8 419) |  |  | AUD |  | (85 284) |
Statement of comprehensive income |  |  |  |  |
Revenue | 48 863 |  |  | AUD |  | 487 479 |
Cost of sales | (38 449) |  |  | AUD |  | (383 584) |
Operating expenses | (6 897) |  |  | AUD |  | (68 809) |
Finance income | 195 |  |  | AUD |  | 1 943 |
Taxation | (1 153) |  |  | AUD |  | (11 505) |

The exchange rates used for the conversions are as follows -

| USD |  | EUR |  | AUD |  | GBP
Closing rate | 13.71 |  |  | 15.96 |  |  | 10.13 |  |  | 17.98 |
Average rate | 12.87 |  |  | 15.34 |  |  | 9.98 |  |  | 17.31 |

49

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
19. Financial Instruments (continued)
Australian dollar denominated loan balance
As a result of the Australian dollar denominated loan balance, the Group’s statement of financial position can be affected by movements in the Australian dollar/Rand exchange rate. Due to the nature of the loan, which is seen as part of the net investment in the foreign operations, any movements are recorded in other comprehensive income.
Sensitivity analysis
A 10 percent strengthening of the Rand against the Australian Dollar at 30 June 2019 would have decreased other comprehensive income and equity by R19.4 million (2018 - R16.9 million). The analysis assumes that all other variables remain constant.
A 10 percent strengthening of the Rand against the following currencies at 30 June 2018 would have increased/(decreased) other comprehensive income/equity and profit or loss by the amounts shown below. The analysis assumes that all other variables, in particular interest rates, remain constant.
Only significant exposure to currencies are included in the analysis below. Where the effect is below RNil, the exposure to the currency is not regarded as significant and excluded from the analysis.

| Equity |  | Profit or (loss) |  | Other comprehensive income
2019 | R000’s |  | R000’s |  | R000’s
EUR | 2.2 |  |  | 2.2 |  |  | — |
AUD | (19 369) |  |  | — |  |  | (19 369) |
2018 |  |  |  |  |
AUD | (16 931) |  |  | — |  |  | (16 931) |

A 10 percent weakening of the Rand against the above currencies would have had the equal but opposite effect on the above currencies to the amounts shown above, on the basis that all other variables remain constant.
Credit risk
Credit risk primarily relates to exposure to loans to subsidiaries (for company only), cash and cash equivalents and trade and other receivables. The Group only deposits surplus cash with well-established financial institutions of high credit standing. Trade receivables comprise a widespread customer base. Ongoing credit evaluations of the financial position of customers is performed, and where appropriate, credit guarantee insurance is purchased. The granting of credit is made on application and is approved by management. At 30 June 2019 management did not consider there to be any material concentration of credit risk which has not been adequately provided for. Management consider the risk of irrecoverability as low. Disclosure of the exposure to credit risk with regards to trade and other receivables is included in note 11.
LOANS TO MEMBERS 1000000
50

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
19. Financial instruments (continued)
Credit risk (continued)
The carrying amount of financial assets represents the maximum credit exposure. The maximum exposure to credit risk at the reporting date was -

| Group |  | Company
| Carrying amount |  | Carrying amount
| 2019 |  | 2018 |  | 2019 |  | 2018
| R000’s |  | R000’s |  | R000’s |  | R000’s
Loans to subsidiaries |  |  |  |  | 171 894 |  |  | 190 152 |
Trade and other receivables | 586 166 |  |  | 476 088 |  |  | 6 261 |  |  | 6 034 |
Cash and cash equivalents | 213 719 |  |  | 251 862 |  |  | 517 |  |  | 282 |
| 799 885 |  |  | 727 950 |  |  | 178 672 |  |  | 196 468 |

Interest rate risk
The Group’s exposure to the risk of changes in market interest rates relates primarily to the finance revenue generating ability of the Group’s surplus cash, due to floating interest rates.
Liquidity risk
The Group monitors its risk to a shortage of funds by using a recurring liquidity planning tool. This tool considers the maturity of both its financial liabilities and financial assets and projected cash flows from operations.
The Group’s objective is to maintain a balance between continuity of funding and flexibility through the use of bank overdrafts, if required.
In terms of the Memorandum of Incorporation the company’s borrowing powers are unlimited.
51

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
19. Financial instruments (continued)
Liquidity risk
The table below summarises the maturity profile of the Group’s financial liabilities at year end, based on contractual undiscounted payments -

| Carrying amount |  | Contractual cash flows |  | Less than 1 year |  | More than 1 year
2019 | R000’s |  | R000’s |  | R000’s |  | R000’s
Non-derivative financial liabilities |  |  |  |  |  |  |
Shareholders’ loans | 3 314 |  |  | 3 314 |  |  | — |  |  | 3 314 |
Trade and other payables | 306 920 |  |  | 306 920 |  |  | 306 920 |  |  | — |
Shareholders’ for dividends | 310 |  |  | 310 |  |  | 310 |  |  | — |
| 310 544 |  |  | 310 544 |  |  | 307 230 |  |  | 3 314 |
2018 |  |  |  |  |  |  |
Non-derivative financial liabilities |  |  |  |  |  |  |
Shareholders’ loans | 3 808 |  |  | 3 808 |  |  | — |  |  | 3 808 |
Trade and other payables | 261 559 |  |  | 261 559 |  |  | 261 559 |  |  | — |
Shareholders’ for dividends | 310 |  |  | 310 |  |  | 310 |  |  | — |
| 265 677 |  |  | 265 677 |  |  | 261 869 |  |  | 3 808 |

The Group has cash and cash equivalents, net of external borrowings, of R214 million (2018 - R252 million) and unutilised credit facilities of R33.5 million (2018 - R33.5 million).
The Company has cash and cash equivalents, net of external borrowings, of R516 799 (2018 - R282 268). The company’s maturity profile of its financial liabilities at year end, based on the contractual undiscounted payments amounts to R568.2 million (2018 - R383.4 million) and consists of the shareholders for dividends and loans from subsidiaries. The contractual cash flows equals the carrying amount and are expected to take place within one year.
Fair value
The carrying values of the Group's cash and cash equivalents, trade and other receivables, trade and other payables and shareholders for dividends, approximates fair value because of the short-term maturity of these instruments.
The carrying value of the Company's cash and cash equivalents, trade and other receivables, shareholders for dividends and loans from subsidiaries approximates fair value because of the short-term maturity of these instruments.
The fair value of the loans to subsidiaries equals their carrying value as they do not bear interest. Therefore the amounts that will be repaid in the future will equate to the carrying amount.
52

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
19. Financial instruments (continued)
Capital management
The primary objective of the Group’s capital management is to ensure that it maintains a strong credit rating and healthy ratios in order to support its business and maximise shareholder value.
The Group manages its capital structure and makes adjustments to it, in light of changes in economic conditions. To maintain or adjust the capital structure, the Group may adjust the dividend payments to shareholders, return capital to shareholders or issue new shares. No changes were made to the objectives, policies or processes during the years ended 30 June 2019 and 30 June 2018.
Capital includes equity attributable to the equity holders of the parent. Refer to note 13 for a quantitative summary of authorised and issued share capital.

|  | Group
|  | 2019 |  | 2018
20. | Commitments | R000’s |  | R000’s
20.1 | Capital commitments |  |  |
| Capital expenditure authorised and contracted for | 229 111 |  |  | 54 593 |
| Capital expenditure authorised, but not yet contracted for | 63 210 |  |  | 110 499 |
|  | 292 321 |  |  | 165 092 |

The proposed capital expenditure will be financed by cash generated from operations.
20.2 Operating commitments
The Group leases certain of its office and other equipment in terms of operating leases. The total future minimum lease payments under non-cancellable operating leases are -

| Group
| 2019 |  | 2018
| R000’s |  | R000’s
Not later than 1 year | 8 507 |  |  | 5 806 |
Between 1 and 5 years | 19 577 |  |  | 16 862 |
| 28 084 |  |  | 22 668 |

53

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

|  | Group |  | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
21. | Notes to the statements of cash flows | R000's |  | R000's |  | R000's |  | R000's
21.1 | Cash generated/(utilised) by operations |  |  |  |  |  |  |
| Profit before taxation | 598 977 |  |  | 553 887 |  |  | 3 120 |  |  | 259 354 |
| Adjustments for - |  |  |  |  |  |  |
| Depreciation | 167 935 |  |  | 147 755 |  |  | — |  |  | — |
| Finance expense | 85 |  |  | 16 |  |  | 8 |  |  | 20 475 |
| Finance income | (25 978) |  |  | (26 212) |  |  | — |  |  | (1) |
| Dividend income |  |  |  |  | — |  |  | (280 493) |
| Movement in provision for rehabilitation | (317) |  |  | 450 |  |  | — |  |  | — |
| Share of equity-accounted earnings | (15 233) |  |  | (13 440) |  |  |  |  |
| Loss/(profit) on disposal of property, plant and equipment | 131 |  |  | (451) |  |  | — |  |  | — |
| Share-based payment expense | 28 607 |  |  | 42 122 |  |  | — |  |  | — |
| Unrealised foreign currency (profit)/loss) | (93 285) |  |  | (22 016) |  |  | — |  |  | — |
| Shares issued to share participants | 68 766 |  |  | 2 552 |  |  | — |  |  | — |
| Changes in working capital |  |  |  |  |  |  |
| Increase in inventories | (45 602) |  |  | (28 448) |  |  | — |  |  | — |
| (Increase)/decrease in trade and other receivables | (129 932) |  |  | (42 396) |  |  | (227) |  |  | 537 |
| (Decrease)/increase in trade and other payables | 58 952 |  |  | (54 902) |  |  | — |  |  | — |
|  | 613 106 |  |  | 558 917 |  |  | 2 901 |  |  | (128) |

54

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

21. | Notes to the statements of cash flows (continued) |  |  |  |  |  |
|  | Group |  | Company
|  | 2019 |  | 2018 |  | 2019 |  | 2018
21.2 | Dividends paid | R000’s |  | R000’s |  | R000’s |  | R000’s
| Shareholders for dividends at beginning of year | (310) |  |  | (310) |  |  | (310) |  |  | (310) |
| Dividends paid | (197 136) |  |  | (129 269) |  |  | — |  |  | — |
| Shareholders for dividends at end of year | 310 |  |  | 310 |  |  | 310 |  |  | 310 |
|  | (197 136) |  |  | (129 269) |  |  | — |  |  | — |
21.3 | Taxation |  |  |  |  |  |  |
| Balance payable at beginning of year | (4 174) |  |  | (1 805) |  |  | (1 125) |  |  | (1 325) |
| Charge for the year | (107 923) |  |  | (127 924) |  |  | (3 239) |  |  | (1 724) |
| SARS interest | (77) |  |  | 380 |  |  | (8) |  |  | (15) |
| Balance payable at end of year | 14 482 |  |  | 4 174 |  |  | 546 |  |  | 1 125 |
|  | (97 692) |  |  | (125 175) |  |  | (3 826) |  |  | (1 939) |

22. Related party transactions
The Company is controlled by Rallen Proprietary Limited, which owns 54.21% (2018: 65.10%) of the Company’s shares. The subsidiaries of the Group are identified in note 9, including loans owed to/(from) the Company.
The directors are listed in Note 23.
There have been no guarantees provided or received for any related party receivables or payables. For the year ended 30 June 2019, the Group has made an impairment allowance relating to amounts owed by related parties of RNil million (2018 - RNil million). The assessment is undertaken each financial year through examining the financial position of the related party and the market in which the related party operates.
Sale transactions
Total sales to Rallen Proprietary Limited’s subsidiary, Italtile Limited, its own stores and its franchised stores amounted to R1 338.4 million (2018 - R1 466.9 million).
Purchase transactions
Total purchases from Ser Export S.R.L, a company in which Italtile Limited has an equity share, amounted to R102.5 million (2018 - R110.5 million).
55

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)
22. Related party transactions (continued)
Outstanding balances
The total value of trade receivable balances owing from Italtile Limited’s own stores and franchised stores amounted to R71.4 million at year end (2018 - R128.2 million).
The total value of the loan to Italtile Limited amounted to R25.6 million and it forms part of the Sundry Debtors at year end.
Management fees
Management fees of R1.2 million (2018 - R1.0 million) were paid to Rallen Proprietary Limited.
Loans to directors
At 30 June 2019 there were no loans to directors or executive management.
Directors’ remuneration and share options
Detailed disclosure of directors’ remuneration is made in note 23.
Dividends received
No dividends were received from subsidiaries during the current year (2018 - R280 million).
Associate
As set out in note 8, dividends of R4.4 million (2018 - R4.3 million) were received from the Group's associate during the year.

| Compensation of key management of the Group - |  |  |
|  | 2019 |  | 2018
|  | R000’s |  | R000’s
| Short-term employee benefits | 11 358 |  |  | 10 888 |
| Share-based payments | 24 452 |  |  | 5 039 |
| Incentives and bonuses | 4 275 |  |  | 5 588 |
| Long-term employee benefits | 1 587 |  |  | 1 432 |
|  | 41 672 |  |  | 22 947 |

Key management is defined as all factory managers.
These figures exclude directors' emoluments which are disclosed in note 23.
56

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

23. | Directors' remuneration
|  |  | Basic remuneration |  | Other benefits |  | Retirement and medical |  | Incentives and bonuses |  | Gain on share scheme awards* |  | Directors' fees |  | Total
| 2019 |  | R000's |  | R000's |  | R000's |  | R000's |  | R000's |  | R000's |  | R000's
| Executive |  |  |  |  |  |  |  |  |  |  |  |  |  |
| LA Foxcroft |  | 2 701 |  |  | 1 009 |  |  | 662 |  |  | 2 387 |  |  | 8 567 |  |  | — |  |  | 15 326 |
| DR Alston (retired 28 November 2017) |  | 886 |  |  | 477 |  |  | 223 |  |  | 1 652 |  |  | — |  |  | — |  |  | 3 238 |
| T Molefakgotla |  | 1 541 |  |  | 670 |  |  | 368 |  |  | 1 190 |  |  | 6 854 |  |  | — |  |  | 10 623 |
| Non-executive |  |  |  |  |  |  |  |  |  |  |  |  |  |
| GAM Ravazzotti 1 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |
| SD Jagoe |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 125 |  |  | 125 |
| EM Mafuna |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 129 |  |  | 129 |
| NS Nematswerani 2 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 159 |  |  | 159 |
| ND Orleyn 3 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 155 |  |  | 155 |
| LEV Ravazzotti Langenhoven 4 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 117 |  |  | 117 |
| RF Ligege |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 117 |  |  | 117 |
|  |  | 5 128 |  |  | 2 156 |  |  | 1 253 |  |  | 5 229 |  |  | 15 421 |  |  | 802 |  |  | 29 989 |
1 | GAM Ravazzotti is paid by Rallen Proprietary Limited for his services as a director of Avikro Industries Proprietary Limited (refer note 22).
2 | Director's fees for NS Nematswerani are paid to AKA Capital Proprietary Limited.
3 | Director's fees for ND Orleyn are paid to Peotona Group Holdings Proprietary Limited.
4 | LEV Ravazzotti is paid by National Avikro Industries Australia Proprietary Limited for her services as a director of Avikro Industries Proprietary Limited.
| The Avikro Industries Proprietary Limited Equity Incentive Scheme ("EIS") was implemented with effect from 1 July 2013. The purpose of the scheme is to incentivise selected employees by giving them the opportunity to acquire shares in Avikro. The scheme will also ensure that the goals of those employees will be aligned with the goals of the other shareholders.
* | IFRS2 expense recognised for executive share scheme awards.

57

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

24. | Directors' remuneration (continued)
|  |  | Basic remuneration |  | Other benefits |  | Retirement and medical |  | Incentives and bonuses |  | Share option payments |  | Directors' fees |  | Total
|  |  | R000's |  | R000's |  | R000's |  | R000's |  | R000's |  | R000's |  | R000's
| 2018 |  |  |  |  |  |  |  |  |  |  |  |  |  |
| Executive |  |  |  |  |  |  |  |  |  |  |  |  |  |
| LA Foxcroft |  | 2 565 |  |  | 378 |  |  | 631 |  |  | 2 821 |  |  | — |  |  | — |  |  | 6 395 |
| DR Alston |  | 2 030 |  |  | 253 |  |  | 510 |  |  | 1 693 |  |  | — |  |  | — |  |  | 4 486 |
| T Molefakgotla |  | 1 312 |  |  | 259 |  |  | 317 |  |  | 783 |  |  | — |  |  | — |  |  | 2 671 |
| Non-executive |  |  |  |  |  |  |  |  |  |  |  |  |  |
| GAM Ravazzotti 1 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |
| SD Jagoe |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 182 |  |  | 182 |
| EM Mafuna |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 144 |  |  | 144 |
| NS Nematswerani 2 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 142 |  |  | 142 |
| ND Orleyn 3 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 171 |  |  | 171 |
| LEV Ravazzotti Langenhoven 4 |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 90 |  |  | 90 |
| RF Ligege |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 152 |  |  | 152 |
|  |  | 5 907 |  |  | 890 |  |  | 1 458 |  |  | 5 297 |  |  | — |  |  | 881 |  |  | 14 433 |

The remuneration of the executive directors are determined by the remuneration committee. Other benefits include the fringe benefit value of a company car for the executive directors.
58

Avikro Industries Proprietary Limited
Notes to the financial statements
for the year ended 30 June 2018 (continued)

24. | Going concern

The directors have made an assessment of the ability of the company, its subsidiaries and associate to continue as a going concern and have no reason to believe that the businesses will not be going concerns in the year ahead.

25. | Events subsequent to reporting date

The Board has declared a final dividend of 400 cents per share on the 18 August 2018.
asdf

ec_70 | Disclosure holding company and ultimate holding company | N/A |  |

59